<?php
// guvenlik kodlarini dahil et
require_once 'inc/guvenlik.php';

// Dropdown menüsü için komponentleri al
$sql = "SELECT id, ad, ek_bilgi FROM komponent ORDER BY id DESC";
$stmt = $baglantim->query($sql);
$components = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Yüklenen dosyaları seçmek için
$sql_files = "SELECT id, file_name, file_path FROM uploads ORDER BY id DESC";
$stmt_files = $baglantim->query($sql_files);
$files = $stmt_files->fetchAll(PDO::FETCH_ASSOC);

// Seçilen komponent için dosyaları al (AJAX isteği)
if (isset($_GET['component_id']) && is_numeric($_GET['component_id'])) {
    $component_id = (int)$_GET['component_id']; // component_id'nin sayı olduğundan emin olalım

    // Komponent ile ilişkili dosya ID'lerini al
    $sql_component_files = "SELECT dosyalar FROM komponent WHERE id = :component_id ORDER BY id DESC";
    $stmt_component_files = $baglantim->prepare($sql_component_files);
    $stmt_component_files->execute([':component_id' => $component_id]);
    $component_files = $stmt_component_files->fetchColumn();

    // Seçilen dosya ID'lerini JSON olarak döndür
    echo json_encode(explode(',', $component_files));
    exit;
}

$response = ['success' => false, 'message' => ''];

// POST verilerini işleme kısmı (Birden fazla komponent ID'si gönderilebilir)
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['component_ids'])) {
        $component_ids = $_POST['component_ids'];
        $selected_files = isset($_POST['file_ids']) ? $_POST['file_ids'] : [];

        // Hiç dosya seçilmemişse, dosyaları NULL yapalım
        $files_str = empty($selected_files) ? NULL : implode(',', $selected_files); // Boş dizi yerine NULL

        // Her bir komponent ID'si için döngü başlatıyoruz
        $component_ids_array = explode(',', $component_ids);
        foreach ($component_ids_array as $component_id) {
            $component_id = (int)$component_id; // component_id'nin sayı olduğundan emin olalım
            $sql_update_komponent = "UPDATE komponent SET dosyalar = :files WHERE id = :component_id ORDER BY id DESC";
            $stmt_update_komponent = $baglantim->prepare($sql_update_komponent);
            $stmt_update_komponent->execute([
                ':files' => $files_str,
                ':component_id' => $component_id
            ]);
        }

        $response['success'] = true;
        $response['message'] = 'Dosyalar başarıyla güncellendi!';
    } else {
        $response['message'] = 'Lütfen en az bir komponent ve dosya seçin.';
    }

    // JSON olarak yanıtı döndür
    echo json_encode($response);
    exit;
}

// Dosya önizleme fonksiyonu
function getFilePreview($fileName, $filePath)
{
    $fileExtension = strtolower(pathinfo($fileName, PATHINFO_EXTENSION));

    // Resim dosyaları için önizleme döndürüyoruz
    if (in_array($fileExtension, ['jpg', 'jpeg', 'png', 'gif', 'webp'])) {
        return '<img src="' . $filePath . '" alt="file preview" style="width: 100%; height: 180px; object-fit: cover; border-radius: 8px;">';
    }

    // Dosya uzantısına göre farklı ikonlar döndürüyoruz
    switch ($fileExtension) {
        case 'pdf':
            return '<i class="fas fa-file-pdf" style="font-size: 100px; color: #e74c3c;"></i>';
        case 'docx':
        case 'doc':
            return '<i class="fas fa-file-word" style="font-size: 100px; color: #3498db;"></i>';
        case 'xlsx':
        case 'xls':
            return '<i class="fas fa-file-excel" style="font-size: 100px; color: #2ecc71;"></i>';
        case 'zip':
        case 'rar':
            return '<i class="fas fa-file-archive" style="font-size: 100px; color: #f39c12;"></i>';
        case 'txt':
            return '<i class="fas fa-file-alt" style="font-size: 100px; color: #7f8c8d;"></i>';
        default:
            return '<i class="fas fa-file" style="font-size: 100px; color: #95a5a6;"></i>';
    }
}

// Çıktı tamponlamasını bitir ve içeriği gönder
ob_end_flush();
?>


<style>


    /* Highlight selected items in the dropdown
    .dropdown-item.selected {
        background-color: #00796b;
        color: white;
    }
    */

    /* Indicate the selected items in the input field */
    #searchInput::placeholder {
        color: #00796b;
        font-style: italic;
    }

    h2 {
        text-align: center;
        color: #00796b;
        font-size: 2.5rem;
        margin-bottom: 40px;
        font-weight: bold;
    }

    .form-label {
        font-size: 1.1rem;
        color: #00796b;
    }

    .form-select {
        border-radius: 10px;
        padding: 12px;
        border: 1px solid #00796b;
        transition: border-color 0.3s ease;
    }

    .form-select:focus {
        border-color: #004d40;
        box-shadow: 0 0 0 0.2rem rgba(0, 77, 64, 0.25);
    }

    .file-item {
        background-color: #ffffff;
        padding: 20px;
        margin-bottom: 20px;
        display: flex;
        align-items: center;
        flex-direction: column;
        border-radius: 15px;
        border: 1px solid #ccc;
        transition: all 0.3s ease;
        cursor: pointer;
        box-shadow: 0 4px 10px rgba(0, 0, 0, 0.05);
    }

    .file-item.selected {
        background-color: #004d40;
        color: #ffffff;
        border-color: #004d40;
        box-shadow: 0 4px 20px rgba(0, 77, 64, 0.2);
    }

    /* Increased file preview size */
    .file-preview {
        width: 200px; /* Set the width */
        height: 200px; /* Set the height */
        background-color: #f0f0f0;
        border-radius: 15px;
        display: flex;
        justify-content: center;
        align-items: center;
        margin-bottom: 15px;
        overflow: hidden; /* Hide overflow */
    }

    .file-preview img {
        width: 100%;
        height: 100%;
        object-fit: cover; /* Make the image cover the div, cropping if necessary */
    }

    .file-preview i {
        font-size: 100px; /* Larger icon size */
        color: #00796b;
    }


    .file-item label {
        font-size: 0.9rem; /* Smaller font size */
        color: #00796b;
        margin-top: 10px;
    }

    .btn-primary {
        background-color: #00796b;
        border-color: #00796b;
        padding: 12px 30px;
        width: 100%; /* or specify a fixed width, like 200px */
        border-radius: 0;
        font-size: 14px;
        font-weight: 500;
        transition: all 0.3s ease;
    }

    .btn-primary:hover {
        background-color: #004d40;
        border-color: #004d40;
    }

    .alert {
        margin-top: 20px;
        font-size: 1.1rem;
    }

    /* Grid layout */
    .file-items {
        display: grid;
        grid-template-columns: repeat(auto-fill, minmax(200px, 1fr));
        gap: 20px;
    }

    /* Select All Button */
    .select-all-btn {
        margin-bottom: 20px;
        font-size: 1.1rem;
        background-color: #00796b;
        color: white;
        border: none;
        padding: 10px 20px;
        border-radius: 10px;
        cursor: pointer;
    }

    .select-all-btn:hover {
        background-color: #004d40;
    }

    /* Dropdown Styles */
    .dropdown-menu {
        max-height: 250px;
        overflow-y: auto;
        width: 100%;
        padding: 10px;
    }

    .search-input {
        width: 100%;
        padding: 10px;
        margin-bottom: 15px;
        border-radius: 10px;
        border: 1px solid #00796b;
        font-size: 1rem;
    }

    .dropdown-item {
        padding: 10px;
        cursor: pointer;
        color: #00796b;
    }

    .dropdown-item:hover {
        background-color: #00796b;
        color: white;
    }

    .highlight {
        background-color: #ff0;
    }

    /* Visual indicator style */
    .selection-indicator {
        width: 15px;
        height: 15px;
        border-radius: 50%;
        background-color: #ccc; /* Default color */
        margin-right: 10px;
        display: inline-block;
    }

    .dropdown-item.selected .selection-indicator {
        background-color: #007bff; /* Active color (e.g., blue) */
    }

    .component-names {
        margin-top: 10px;
        font-size: 1rem;
        color: #00796b;
    }

    .component-name {
        display: inline-block;
        background-color: #e0f2f1;
        padding: 5px 10px;
        border-radius: 5px;
        margin-right: 5px;
        font-size: 1rem;
    }

    #fileItems {
        padding-bottom: 40px; /* Alt alana biraz boşluk bırakmak için */
    }

    #fileItems.selected {
        border-bottom: 1px solid #4fa3f7; /* Mavi renkli alt çizgi */
    }

    #goToTop, #goToBottom {
        z-index: 9999; /* Ensure the buttons appear above other content */
        position: fixed;
        right: 10px;
        background-color: #007bff;
        border-radius: 50%;
        width: 40px;
        height: 40px;
        display: none;
        padding: 10px;
        font-size: 18px;
        color: white;
        border: none;
        cursor: pointer;
        box-shadow: 0 2px 6px rgba(0, 0, 0, 0.2);
        text-align: center;
    }

    #goToTop {
        bottom: 60px; /* Position above Go to Bottom button */
    }

    #goToBottom {
        bottom: 10px; /* Position at the bottom of the page */
    }

    #goToTop:hover, #goToBottom:hover {
        background-color: #0056b3; /* Darken on hover */
    }

</style>

<h2></h2>
<div class="form-control">
    <label for="component_id" class="form-label">Seçilen ürünler:</label>

    <div id="selectedTags" class="mt-2">
        <!-- Seçilen etiketler burada görünecek -->
    </div>
</div>

<form method="POST" id="updateForm">

    <!-- Dropdown for component selection -->
    <div class="mb-4">
        <label for="component_id" class="form-label"></label>
        <div class="dropdown">
            <input type="text" class="form-control search-input" id="searchInput" placeholder="Ürünleri arayın..."
                   data-bs-toggle="dropdown">
            <ul class="dropdown-menu" id="dropdownMenu" aria-labelledby="searchInput">
                <?php foreach ($components as $component): ?>
                    <li>
                        <a class="dropdown-item" href="#"
                           data-id="<?php echo htmlspecialchars($component['id'], ENT_QUOTES, 'UTF-8'); ?>">
                            <!-- Replace checkbox with a visual selection indicator -->
                            <span class="selection-indicator"></span> <!-- Visual indicator for selection -->
                            <?php echo htmlspecialchars($component['ad'], ENT_QUOTES, 'UTF-8') . ' > ' . htmlspecialchars($component['ek_bilgi'], ENT_QUOTES, 'UTF-8'); ?>
                        </a>
                    </li>
                <?php endforeach; ?>
            </ul>

        </div>

    </div>

    <!-- Select All / Deselect All Button -->
    <button type="button" class="select-all-btn" id="selectAll">Tümünü Seç</button>
    <button type="button" class="select-all-btn" id="iliskisizleriSec">İlişiksizler</button>


    <!-- Dosya Arama Formu -->
    <div class="mb-4">
        <label for="fileSearchInput" class="form-label">Dosya Arayın:</label>
        <input type="text" class="form-control search-input" id="fileSearchInput" placeholder="Dosya adı yazın...">
    </div>

    <!-- Files Grid -->
    <div class="file-items" id="fileItems">
        <?php foreach ($files as $file): ?>
            <div class="file-item" data-file-id="<?php echo htmlspecialchars($file['id'], ENT_QUOTES, 'UTF-8'); ?>">
                <div class="file-preview">
                    <!-- Dosya önizlemesi -->
                    <?php
                    $extension = pathinfo($file['file_name'], PATHINFO_EXTENSION);
                    if (in_array($extension, ['jpg', 'jpeg', 'png', 'gif', 'webp'])): ?>
                        <img src="<?php echo htmlspecialchars($file['file_path'], ENT_QUOTES, 'UTF-8'); ?>"
                             alt="<?php echo htmlspecialchars($file['file_name'], ENT_QUOTES, 'UTF-8'); ?>"/>
                    <?php elseif ($extension === 'pdf'): ?>
                        <i class="fas fa-file-pdf" style="font-size: 100px; color: #e74c3c;"></i>
                    <?php else : ?>
                        <i class="fas fa-file-alt"></i>
                    <?php endif; ?>
                </div>

                <div class="component-names">
                    <?php
                    // Komponentleri alalım
                    $sql_component_names = "SELECT id, ad FROM komponent WHERE FIND_IN_SET(:file_id, dosyalar)";
                    $stmt_component_names = $baglantim->prepare($sql_component_names);
                    $stmt_component_names->execute([':file_id' => $file['id']]);
                    $components = $stmt_component_names->fetchAll(PDO::FETCH_ASSOC);
                    ?>
                    <label><?php echo htmlspecialchars(pathinfo($file['file_name'], PATHINFO_FILENAME), ENT_QUOTES, 'UTF-8'); ?></label>
                    <div id="tagsContainer" data-file-id="<?php echo htmlspecialchars($file['id'], ENT_QUOTES, 'UTF-8'); ?>">
                        <?php foreach ($components as $component): ?>
                            <span class="badge bg-primary me-1 mb-1 component-tag"
                                  data-component-id="<?php echo htmlspecialchars($component['id'], ENT_QUOTES, 'UTF-8'); ?>">
                <?php echo htmlspecialchars($component['ad'], ENT_QUOTES, 'UTF-8'); ?>
                <button type="button" class="btn-close btn-close-white ms-1" aria-label="Close"></button>
            </span>
                        <?php endforeach; ?>
                    </div>
                </div>

            </div>
        <?php endforeach; ?>
    </div>


    <!-- Response Message -->
    <div id="responseMessage"></div>
    <div id="noRecordsMessage" style="display: none;">
        <p>İlişiksiz dosya bulunamadı.</p>
    </div>
    <!-- Hidden Component ID input -->
    <input type="hidden" name="component_id" id="component_id" value="">

    <!-- Submit Button -->
    <button type="submit" class="btn btn-primary mt-4">Seçili Dosyaları Ürüne Kaydet</button>


</form>
<button id="goToTop" class="btn btn-primary position-fixed bottom-0 end-0 m-3">
    <i class="fas fa-arrow-up"></i>
</button>
<button id="goToBottom" class="btn btn-primary position-fixed bottom-0 end-0 m-3">
    <i class="fas fa-arrow-down"></i>
</button>
<script>
    $(document).ready(function () {
        var debounceTimeout;

        // Dropdown menu item selection
        $('#dropdownMenu').on('click', '.dropdown-item', function () {
            var componentId = $(this).data('id');
            var componentName = $(this).text().trim();

            // Toggle the 'selected' class and the visual indicator
            $(this).toggleClass('selected');
            $(this).find('.selection-indicator').toggleClass('active'); // Visual feedback for selection

            // Update the selected components list and tags
            updateSelectedComponents();

            // Sync the file previews with the selected components
            syncFilePreviews(componentId, $(this).hasClass('selected'));

            // Update the Select All button after selection change
            updateSelectAllButton();
        });

        // Update the hidden input field and tags with selected components
// Update the hidden input field and tags with selected components
        function updateSelectedComponents() {
            var selectedComponents = [];
            $('#dropdownMenu').find('.dropdown-item.selected').each(function () {
                selectedComponents.push($(this).data('id'));
            });
            $('#component_id').val(selectedComponents.join(','));  // Store selected component IDs

            // Display selected components as tags
            updateTags(selectedComponents);
        }

        // Display selected components as tags
        function updateTags(selectedComponents) {
            var tagContainer = $('#selectedTags');
            tagContainer.empty();  // Clear previous tags

            selectedComponents.forEach(function (componentId) {
                var componentName = $('#dropdownMenu').find('[data-id="' + componentId + '"]').text().trim();
                var tag = $('<span class="badge bg-primary me-1 mb-1">').text(componentName);
                var removeBtn = $('<button class="btn-close btn-close-white ms-1" type="button"></button>');

                // Remove tag when close button is clicked
                removeBtn.on('click', function () {
                    $('#dropdownMenu').find('.dropdown-item[data-id="' + componentId + '"]').removeClass('selected');
                    tag.remove();
                    updateSelectedComponents();  // Update selected components list
                    syncFilePreviews(componentId, false); // Deselect related file previews
                });

                tag.append(removeBtn);
                tagContainer.append(tag);
            });
        }

        // Sync the selection of file previews based on the selected components
        function syncFilePreviews(componentId, isSelected) {
            // Fetch the related file items based on the selected component
            $.get('iliskilendir.php', {component_id: componentId}, function (response) {
                var selectedFileIds = response;  // Array of file IDs related to the selected component

                // Loop through each file item and update its selection state
                $('.file-item').each(function () {
                    var fileId = $(this).data('file-id');

                    // If the component is selected, select related file previews, otherwise deselect them
                    if (selectedFileIds.includes(fileId.toString())) {
                        $(this).toggleClass('selected', isSelected);
                    }
                });

                // Update the Select All button after file preview update
                updateSelectAllButton();
            });
        }

        // Filter dropdown options based on search input
        $('#searchInput').on('input', function () {
            clearTimeout(debounceTimeout);
            var searchText = $(this).val().toLowerCase();
            debounceTimeout = setTimeout(function () {
                $('#dropdownMenu').find('.dropdown-item').each(function () {
                    var itemText = $(this).text().toLowerCase();
                    $(this).toggle(itemText.includes(searchText));
                });
            }, 300);
        });

        // Open dropdown menu when input field is focused
        $('#searchInput').on('focus', function () {
            $('#dropdownMenu').show();  // Show the dropdown menu when the input field is focused
        });

        // Close dropdown menu if clicked outside
        $(document).on('click', function (event) {
            if (!$(event.target).closest('#searchInput').length && !$(event.target).closest('#dropdownMenu').length) {
                $('#dropdownMenu').hide();  // Hide the dropdown menu when clicked outside
            }
        });

        // Handle Select All / Deselect All button functionality
        $('#selectAll').on('click', function () {
            var buttonText = $(this).text().trim();

            // If the button text is "Select All", select all items
            $('.file-item').toggleClass('selected', buttonText === 'Tümünü Seç');
            updateSelectAllButton();
        });

        // Toggle selection when clicking on the file preview itself
        $('#fileItems').on('click', '.file-item', function () {
            $(this).toggleClass('selected');
            updateSelectAllButton();
        });

        // Function to update Select All button text based on the selection state
        function updateSelectAllButton() {
            var totalItems = $('.file-item').length;
            var selectedItems = $('.file-item.selected').length;

            if (totalItems === selectedItems) {
                $('#selectAll').text('Seçimleri Kaldır');
            } else {
                $('#selectAll').text('Tümünü Seç');
            }
        }

        $('#updateForm').on('submit', function (e) {
            e.preventDefault();

            // Seçilen ürünleri almak için tüm işaretlenen dropdown item'ları kontrol et
            var componentIds = [];
            $('.dropdown-item.selected').each(function () {
                componentIds.push($(this).data('id')); // Dropdown item'ların 'data-id' özelliğini al
            });

            // Eğer hiçbiri seçilmediyse, uyarı göster
            if (componentIds.length === 0) {
                alert('Please select at least one component!');
                return;
            }

            var selectedFileIds = [];
            $('.file-item.selected').each(function () {
                selectedFileIds.push($(this).data('file-id'));
            });

            $.post('iliskilendir.php', {
                component_ids: componentIds.join(','), // Çoklu component_id'yi virgülle ayırarak gönder
                file_ids: selectedFileIds     // Send selected file IDs
            }, function (response) {
                if (response.success) {
                    var successMessage = `
            <div class="alert alert-success alert-dismissible fade show" role="alert">
                <strong>Success!</strong> ${response.message}
                <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
            </div>
        `;
                    $('#responseMessage').html(successMessage).fadeIn(300);

                    // Auto-hide the success message after 4 seconds
                    setTimeout(function () {
                        $('#responseMessage .alert').fadeOut(300);
                    }, 4000);

                    // Reset the selected items after the form is submitted
                    $('.dropdown-item').removeClass('selected'); // Deselect all dropdown items
                    $('.file-item').removeClass('selected');         // Remove selected class from file items
                    $('#selectAll').text('Tümünü Seç');               // Reset Select All button text

                    // Clear the tags (selected components) after form submission
                    $('#selectedTags').empty(); // Remove all tags

                    // Remove 'selected' class from dropdown items and reset the input field placeholder style
                    $('#searchInput').attr('placeholder', 'Ürünleri arayın...'); // Reset placeholder

                    // Now, update the corresponding file items on the page (AJAX call to get updated file content)
                    $.each(selectedFileIds, function (index, fileId) {
                        $.get('getFileComponents.php', {file_id: fileId}, function (fileResponse) {
                            if (fileResponse.success) {
                                // Find the corresponding file item div and update it
                                var fileItemDiv = $('.file-item[data-file-id="' + fileId + '"]');

                                // Update file preview
                                var extension = fileResponse.file.extension;
                                var previewHtml = '';
                                if (['jpg', 'jpeg', 'png', 'gif', 'webp'].includes(extension)) {
                                    previewHtml = `<img src="${fileResponse.file.file_path}" alt="${fileResponse.file.file_name}" />`;
                                } else if (extension === 'pdf') {
                                    previewHtml = `<embed src="${fileResponse.file.file_path}" type="application/pdf" width="100" height="100">`;
                                } else {
                                    previewHtml = '<i class="fas fa-file-alt"></i>';
                                }
                                fileItemDiv.find('.file-preview').html(previewHtml);

                                // Update component names and tags
                                var tagsHtml = '';
                                $.each(fileResponse.components, function (i, component) {
                                    tagsHtml += `
                            <span class="badge bg-primary me-1 mb-1 component-tag" data-component-id="${component.id}">
                                ${component.ad}
                                <button type="button" class="btn-close btn-close-white ms-1" aria-label="Close"></button>
                            </span>
                        `;
                                });
                                fileItemDiv.find('#tagsContainer').html(tagsHtml);
                            }
                        }, 'json');
                    });
                } else {
                    $('#responseMessage').html('<div class="alert alert-danger">' + response.message + '</div>');
                }
            }, 'json');
        });


        $(document).on('click', '.component-tag .btn-close', function () {
            var fileId = $(this).closest('.file-item').data('file-id');
            var componentId = $(this).closest('.component-tag').data('component-id');

            // Silinen tag'ı DOM'dan kaldırıyoruz
            $(this).closest('.component-tag').remove();

            // Veritabanında güncelleme yapmak için AJAX isteği gönderiyoruz
            $.ajax({
                url: 'sil_tag.php', // AJAX isteği göndereceğimiz PHP dosyası
                method: 'POST',
                data: {
                    component_id: componentId,
                    file_id: fileId
                },
                dataType: 'json',  // Response'u JSON olarak alacağımızı belirtiyoruz
                success: function (response) {
                    console.log('Response from server:', response); // Yanıtı konsola yazdırarak kontrol edelim

                    if (response && response.success === true) {
                        console.log('Tag successfully removed from the database!');
                    } else {
                        console.log('Error removing tag from the database: ' + (response.message || 'Unknown error'));
                    }
                },
                error: function (xhr, status, error) {
                    console.error('AJAX error: ' + error);  // Hata mesajını konsola yazdırın
                    console.log('Response from server:', xhr.responseText);  // Sunucudan dönen yanıtı burada kontrol edin
                }
            });
        });


        // Dosya önizlemesini seçmeyi engellemek için tagsContainer üzerine tıklama olayını engelliyoruz
        $('#fileItems').on('click', '#tagsContainer', function (event) {
            // Eğer tıklanan element bir 'btn-close' (tag silme butonu) değilse, dosya önizlemesini seçmeyi engelle
            if (!$(event.target).hasClass('btn-close')) {
                event.stopPropagation(); // Tıklamanın daha ileriye gitmesini engeller (dosya önizlemesi seçilmez)
            }
        });


        var debounceTimeout;
        // Arama formunu yönetiyoruz
        $('#fileSearchInput').on('input', function () {
            clearTimeout(debounceTimeout);
            var searchText = $(this).val().toLowerCase();
            debounceTimeout = setTimeout(function () {
                var found = false; // Arama sonucunun bulunup bulunmadığını kontrol etmek için bir değişken

                $('#fileItems').find('.file-item').each(function () {
                    var fileName = $(this).find('label').text().toLowerCase();
                    if (fileName.includes(searchText)) {
                        $(this).show(); // Eşleşen öğeyi göster
                        $(this).css('padding', '10px'); // Eşleşen öğelere padding ekle
                        found = true; // Eşleşme bulundu
                    } else {
                        $(this).hide(); // Eşleşmeyen öğeyi gizle
                        $(this).css('padding', '20px'); // Eşleşmeyen öğelere padding ekle
                    }
                });
            }, 300); // Arama kutusuna her yazıldığında 300ms gecikme
        });

        // Seçim işlemleri için diğer scriptler devam edecek...


        var debounceTimeout;

        // Scroll to the top
        $('#goToTop').on('click', function () {
            $('html, body').animate({scrollTop: 0}, 'smooth');
        });

        // Scroll to the bottom
        $('#goToBottom').on('click', function () {
            $('html, body').animate({scrollTop: $(document).height()}, 'smooth');
        });

        // Show/Hide scroll buttons based on scroll position
        $(window).on('scroll', function () {
            var scrollPosition = $(this).scrollTop();
            var documentHeight = $(document).height();
            var windowHeight = $(window).height();

            // Show "Go to Top" when scrolled down 100px or more
            if (scrollPosition > 100) {
                $('#goToTop').fadeIn();
            } else {
                $('#goToTop').fadeOut();
            }

            // Show "Go to Bottom" when the user hasn't scrolled to the bottom
            if (scrollPosition < documentHeight - windowHeight - 100) {
                $('#goToBottom').fadeIn();
            } else {
                $('#goToBottom').fadeOut();
            }


            // Initial check on page load to show buttons based on scroll position

        });
        $(window).trigger('scroll');

    });

 $(document).ready(function () {
        // "İlişiksiz" butonuna tıklama işlemi
        $('#iliskisizleriSec').on('click', function () {
            var isSelecting = $(this).data('selecting') || false;  // Butonun hangi durumda olduğunu takip ediyoruz

            if (isSelecting) {
                // Tekrar tıklanırsa, tüm dosya öğelerini göster ve "Kayıt Bulunamadı" mesajını kaldır
                $('.file-item').show();  // Tüm dosya öğelerini göster
                $('#noRecordsMessage').hide();  // "Kayıt Bulunamadı" mesajını gizle
                $(this).text('İlişiksizler');  // Buton metnini eski haline getir
            } else {
                var foundNonRelated = false;  // Tag'ı olmayan dosya önizlemesi bulduğumuzda bu true olacak

                // İlk tıklama: tag'ı olmayan dosya öğelerini göster
                $('.file-item').each(function () {
                    var tagsContainer = $(this).find('#tagsContainer');
                    // Eğer tag yoksa, bu dosya öğesini göster
                    if (tagsContainer.children('.component-tag').length === 0) {
                        $(this).show();  // Dosya öğesini göster
                        foundNonRelated = true;  // Tag'sız dosya bulundu
                    } else {
                        $(this).hide();  // Tag'ı olan dosya öğesini gizle
                    }
                });

                // Eğer tag'ı olmayan dosya bulunmazsa, "Kayıt Bulunamadı" mesajını göster
                if (!foundNonRelated) {
                    $('#noRecordsMessage').show();  // "Kayıt Bulunamadı" mesajını göster
                } else {
                    $('#noRecordsMessage').hide();  // Mesajı gizle
                }

                $(this).text('Tümünü Göster');  // Buton metnini değiştir
            }

            // Durumu değiştirelim
            $(this).data('selecting', !isSelecting);
        });
    });



</script>
