<?php
if (session_status() == PHP_SESSION_NONE) {
    session_start(); // Oturum başlat
    ob_start(); // Çıktı tamponlamayı başlatıyoruz, header hatalarını engellemek için.
}
// CSRF Token kontrolü
function generate_csrf_token() {
    if (empty($_SESSION['csrf_token'])) {
        $_SESSION['csrf_token'] = bin2hex(random_bytes(32)); // Güvenli token oluşturma
    }
    return $_SESSION['csrf_token'];
}

function validate_csrf_token($token) {
    return isset($_SESSION['csrf_token']) && hash_equals($_SESSION['csrf_token'], $token);
}

// Çıkış yap butonuna tıklanmışsa
if (isset($_GET['logout']) && $_GET['logout'] == 'true') {
    // Eğer kullanıcı oturum açmışsa
    if (isset($_SESSION['eposta'])) {
        // Oturumdaki veriyi temizle
        unset($_SESSION['eposta']);

        // Oturumu sonlandır
        session_destroy();

        // Güvenli çıkış için çerezleri temizle
        setcookie('epostaHatirla', '', time() - 3600, '/', null, true, true); // Secure ve HTTP only
        setcookie('parolaHatirla', '', time() - 3600, '/', null, true, true); // Secure ve HTTP only
    }
    // Çıkış işlemi tamamlandığında, kullanıcıyı ana sayfaya yönlendir
    header("Location: index.php");
    exit;
}

if (isset($_SESSION['eposta'])) {
    include_once 'inc/baglan.php';


    $sayfa_basliklari = [
        'KomponentListesi' => 'Komponent Listesi',
        'KomponentEkle' => 'Ürün Ekle',
        'KomponentDuzenle' => 'Ürün Düzenle',
        'KategoriEkle' => 'Kategori ekle',
        'KategoriListesi' => 'Kategori Listesi',
        'KategoriDuzenle' => 'Kategori Düzenle',
        'PaketListesi' => 'Paket Listesi',
        'PaketDuzenle' => 'Paket Düzenle',
        'PaketEkle' => 'Paket Ekle',
        'LokasyonListesi' => 'Lokasyon Listesi',
        'LokasyonDuzenle' => 'Lokasyon Düzenle',
        'LokasyonEkle' => 'Lokasyon Ekle',
        'UreticiListesi' => 'Üretici Listesi',
        'UreticiDuzenle' => 'Üretici Düzenle',
        'UreticiEkle' => 'Üretici Ekle',
        'TedarikciListesi' => 'Tedarikçi Listesi',
        'TedarikciDuzenle' => 'Tedarikçi Düzenle',
        'TedarikciEkle' => 'Tedarikçi Ekle',
        'KomponentDetay' => 'Ürün Detayları',
        'DosyaListesi' => 'Dosya Listesi',
        'DosyaYukle' => 'Dosya Yükle',
        'DosyaIliskile' => 'Dosya İlişikle',
    ];

    $title = isset($_GET['sayfa']) && isset($sayfa_basliklari[$_GET['sayfa']])
        ? $sayfa_basliklari[$_GET['sayfa']]
        : 'Ürün Listesi';

    ?>

    <!DOCTYPE html>
    <html lang="tr">
    <head>
        <meta charset="utf-8">
        <meta name="viewport" content="width=device-width, initial-scale=1">
        <title><?php echo htmlspecialchars($title);?></title>
        <script src="js/jquery-3.7.1.js"></script>
        <link href="css/bootstrap.min.css" rel="stylesheet">
        <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.7.2/css/all.min.css">
        <link rel="stylesheet" href="https://fonts.googleapis.com/css?family=Material+Icons+Outlined">
        <link href="css/dataTables.dataTables.css" rel="stylesheet" type="text/css"/>
        <link href="css/fixedColumns.dataTables.css" rel="stylesheet" type="text/css"/>
        <link href="css/responsive.dataTables.css" rel="stylesheet" type="text/css"/>
        <link href="css/colReorder.dataTables.css" rel="stylesheet" type="text/css"/>
        <link href="css/dataTables.searchHighlight.css" rel="stylesheet" type="text/css"/>
        <link href="css/searchBuilder.dataTables.min.css" rel="stylesheet" type="text/css"/>
        <link href="css/dataTables.dateTime.min.css" rel="stylesheet" type="text/css"/>
        <link href="css/buttons.dataTables.css" rel="stylesheet" type="text/css"/>
        <link href="css/tagify.css" rel="stylesheet" type="text/css" />
        <link href="css/ozel.css" rel="stylesheet" type="text/css"/>
        <script src="js/dataTables.min.js"></script>
        <script src="js/dataTables.responsive.js"></script>
        <script src="js/responsive.dataTables.js"></script>
        <script src="js/dataTables.colReorder.js"></script>
        <script src="js/colReorder.dataTables.js"></script>
        <script src="js/dataTables.searchHighlight.min.js"></script>
        <script src="js/jquery.highlight.js"></script>
        <script src="js/dataTables.buttons.js"></script>
        <script src="js/buttons.dataTables.js"></script>
        <script src="js/buttons.colVis.min.js"></script>
        <script src="js/fixedColumns.dataTables.js"></script>
        <script src="js/dataTables.fixedColumns.js"></script>
        <script src="js/searchBuilder.dataTables.js"></script>
        <script src="js/dataTables.searchBuilder.js"></script>
        <script src="js/dataTables.dateTime.min.js"></script>
        <script src="js/jszip.min.js"></script>
        <script src="js/pdfmake.min.js"></script>
        <script src="js/vfs_fonts.js"></script>
        <script src="js/buttons.html5.min.js"></script>
        <script src="js/jquery-migrate-3.5.2.min.js"></script>
        <script src="js/jquery-ui.min.js"></script>
        <script src="js/jquery.validate.min.js"></script>
        <script src="js/messages_tr.min.js"></script>
        <link href="summernote-0.9.0-dist/summernote-lite.css" rel="stylesheet">
        <script src="summernote-0.9.0-dist/summernote-lite.js"></script>
        <style>
            /* Yükleme ekranı */
            #loader {
                position: fixed;
                top: 0;
                left: 0;
                width: 100%;
                height: 100%;
                background: rgba(0, 0, 0, 0.5);
                display: flex;
                justify-content: center;
                align-items: center;
                z-index: 9999;
            }

            /* Dönen ikon */
            .spinner {
                border: 4px solid #f3f3f3; /* Gri arka plan */
                border-top: 4px solid #3498db; /* Mavi renkli üst kısım */
                border-radius: 50%;
                width: 50px;
                height: 50px;
                animation: spin 1s linear infinite; /* Dönen animasyon */
            }

            /* Dönen animasyon */
            @keyframes spin {
                0% { transform: rotate(0deg); }
                100% { transform: rotate(360deg); }
            }

            /* Sayfa içerikleri */
            #content, #content1 {
                display: none;
            }
        </style>
    </head>

    <body>
    <!-- Yükleme ekranı -->
    <div id="loader">
        <div class="spinner"></div> <!-- Dönen yükleme ikonu -->
    </div>

    <div id="content" class="container-fluid">
        <ul class="nav nav-tabs">
            <li class="nav-item">
                <a class="nav-link active" aria-current="page" href="index.php">Anasayfa</a>
            </li>

            <li class="nav-item dropdown">
                <a class="nav-link dropdown-toggle" data-bs-toggle="dropdown" href="#" role="button"
                   aria-expanded="false">Ürün</a>
                <ul class="dropdown-menu">
                    <li><a class="dropdown-item" href="index.php?sayfa=KomponentListesi">Ürün Listesi</a></li>
                    <li><a class="dropdown-item" href="index.php?sayfa=KomponentEkle">Ürün Ekle</a></li>
                </ul>
            </li>
            <li class="nav-item dropdown">
                <a class="nav-link dropdown-toggle" data-bs-toggle="dropdown" href="#" role="button"
                   aria-expanded="false">Kategori</a>
                <ul class="dropdown-menu">
                    <li><a class="dropdown-item" href="index.php?sayfa=KategoriListesi">Kategori Listesi</a></li>
                    <li><a class="dropdown-item" href="index.php?sayfa=KategoriEkle">Kategori Ekle</a></li>
                </ul>
            </li>
            <li class="nav-item dropdown">
                <a class="nav-link dropdown-toggle" data-bs-toggle="dropdown" href="#" role="button"
                   aria-expanded="false">Paket</a>
                <ul class="dropdown-menu">
                    <li><a class="dropdown-item" href="index.php?sayfa=PaketListesi">Paket Listesi</a></li>
                    <li><a class="dropdown-item" href="index.php?sayfa=PaketEkle">Paket Ekle</a></li>
                </ul>
            </li>
            <li class="nav-item dropdown">
                <a class="nav-link dropdown-toggle" data-bs-toggle="dropdown" href="#" role="button"
                   aria-expanded="false">Lokasyon</a>
                <ul class="dropdown-menu">
                    <li><a class="dropdown-item" href="index.php?sayfa=LokasyonListesi">Lokasyon Listesi</a></li>
                    <li><a class="dropdown-item" href="index.php?sayfa=LokasyonEkle">Lokasyon Ekle</a></li>
                </ul>
            </li>
            <li class="nav-item dropdown">
                <a class="nav-link dropdown-toggle" data-bs-toggle="dropdown" href="#" role="button"
                   aria-expanded="false">Üretici</a>
                <ul class="dropdown-menu">
                    <li><a class="dropdown-item" href="index.php?sayfa=UreticiListesi">Üretici Listesi</a></li>
                    <li><a class="dropdown-item" href="index.php?sayfa=UreticiEkle">Üretici Ekle</a></li>
                </ul>
            </li>
            <li class="nav-item dropdown">
                <a class="nav-link dropdown-toggle" data-bs-toggle="dropdown" href="#" role="button"
                   aria-expanded="false">Tedarikçi</a>
                <ul class="dropdown-menu">
                    <li><a class="dropdown-item" href="index.php?sayfa=TedarikciListesi">Tedarikçi Listesi</a></li>
                    <li><a class="dropdown-item" href="index.php?sayfa=TedarikciEkle">Tedarikçi Ekle</a></li>
                </ul>
            </li>

            <li class="nav-item dropdown">
                <a class="nav-link dropdown-toggle" data-bs-toggle="dropdown" href="#" role="button"
                   aria-expanded="false">Dosyalar</a>
                <ul class="dropdown-menu">
                    <li><a class="dropdown-item" href="index.php?sayfa=DosyaListesi">Dosya Listesi</a></li>
                    <li><a class="dropdown-item" href="index.php?sayfa=DosyaYukle">Dosya Yükle</a></li>
                    <li><a class="dropdown-item" href="index.php?sayfa=DosyaEslesenler">Eşleşmişler</a></li>
                    <li><a class="dropdown-item" href="index.php?sayfa=DosyaIliskile">Dosya İliştir</a></li>
                </ul>
            </li>
            <li class="nav-item dropdown">
                <a class="nav-link dropdown-toggle" data-bs-toggle="dropdown" href="#" role="button"
                   aria-expanded="false">Üye</a>
                <ul class="dropdown-menu">
                    <li><a class="dropdown-item" href="index.php?sayfa=UyeSifreDegistir">Bilgilerim</a></li>
                    <!-- Çıkış işlemi için form -->
                    <form action="index.php" method="POST" style="display: inline;">
                        <input type="hidden" name="csrf_token" value="<?php echo generate_csrf_token(); ?>">
                        <li class="nav-item">
                            <button class="nav-link" type="submit" name="logout" value="true">Çıkış Yap</button>
                        </li>
                    </form>
                </ul>
            </li>
        </ul>

    </div>

    <div id="content1" class="container-fluid" style="margin-top: 40px;">

        <?php
        if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['logout'])) {
            // CSRF token doğrulaması
            if (validate_csrf_token($_POST['csrf_token'])) {
                if (isset($_SESSION['eposta'])) {
                    // Oturum sonlandırma işlemi
                    unset($_SESSION['eposta']);
                    session_destroy();
                    setcookie('epostaHatirla', '', time() - 3600, '/', null, true, true);
                    setcookie('parolaHatirla', '', time() - 3600, '/', null, true, true);
                    header("Location: index.php");
                    exit;
                }
            } else {
                echo "Geçersiz CSRF token!";
            }
        }

        // Sayfa içeriği yükleme
        $sayfa = 'anasayfa';
        if (array_key_exists('sayfa', $_GET)) {
            $sayfa = htmlspecialchars($_GET['sayfa']);  // XSS koruması için htmlspecialchars kullanıldı
        }

        // VARSAYILAN SAYFA
        $sayfa = 'anasayfa';

        // sayfa varsa degeri degistir
        if (array_key_exists('sayfa', $_GET)) {
            $sayfa = htmlspecialchars($_GET['sayfa']);  // XSS koruması için htmlspecialchars kullanıldı
        }
        switch ($sayfa) {
            case 'DosyaListesi':
                include_once 'list_files.php';
                break;

            case 'DosyaYukle':
                include_once 'dosya_yukle.php';
                break;

            case 'DosyaIliskile':
                include_once 'iliskilendir.php';
                break;

            case 'DosyaEslesenler':
                include_once 'dosya_cek.php';
                break;

            case 'KategoriDuzenle':
                include_once 'kategori-duzenle.php';
                break;

            case 'KomponentEkle':
                include_once 'komponent-ekleme-formu.php';
                break;

            case 'KomponentDuzenle':
                include_once 'komponent-duzenle-formu.php';
                break;

            case 'KategoriListesi':
                include_once 'kategori-listele.php';
                break;

            case 'KategoriEkle':
                include_once 'kategori-ekle.php';
                break;

            case 'UyeSifreDegistir':
                include_once 'uye-sifre-degistir.php';
                break;

            case 'PaketListesi':
                include_once 'paket-listele.php';
                break;

            case 'PaketEkle':
                include_once 'paket-ekle.php';
                break;

            case 'PaketDuzenle':
                include_once 'paket-duzenle.php';
                break;


            case 'LokasyonListesi':
                include_once 'lokasyon-listele.php';
                break;

            case 'LokasyonEkle':
                include_once 'lokasyon-ekle.php';
                break;

            case 'LokasyonDuzenle':
                include_once 'lokasyon-duzenle.php';
                break;

            case 'UreticiListesi':
                include_once 'uretici-listele.php';
                break;

            case 'UreticiEkle':
                include_once 'uretici-ekle.php';
                break;


            case 'UreticiDuzenle':
                include_once 'uretici-duzenle.php';
                break;


            case 'TedarikciListesi':
                include_once 'tedarikci-listele.php';
                break;

            case 'TedarikciEkle':
                include_once 'tedarikci-ekle.php';
                break;

            case 'TedarikciDuzenle':
                include_once 'tedarikci-duzenle.php';
                break;

            case 'KomponentDetay':
                include_once 'komponent-detay.php';
                break;

            case 'anasayfa':
            default:
                include_once 'komponent-listele.php';
                break;

        }
        ?>

    </div>
    <script>
        $(document).ready(function() {
            // Sayfa yüklendiğinde içerikleri sırayla göster
            $('#loader').fadeOut(500, function() {
                $('#content').fadeIn(500, function() {
                    $('#content1').fadeIn(500); // İlk içerik göründükten sonra ikinciyi göster
                });
            });
        });
    </script>
    <script src="js/popper.min.js"></script>
    <script src="js/bootstrap.min.js"></script>
    <script src="js/tagify.js"></script>
    <script src="js/tagify.polyfills.min.js"></script>
    <script src="js/script.js"></script> <!-- jquery kodlarimizi cekelim -->

    </body>
    </html>

    <?php
} else {
    require_once 'giris.php';
}
?>