$(document).ready(function () {
    // Menü açma/kapama fonksiyonu
    function toggleMenu(selectClass, textClass) {
        $(document).on("click", textClass, function () {
            var select = $(this).next(selectClass);
            select.removeClass("d-none");
            $(this).addClass("d-none");
        });

        $(document).on("change", selectClass, function () {
            var textElement = $(this).prev(textClass);
            textElement.text($(this).find(":selected").text());
            $(this).addClass("d-none");
            textElement.removeClass("d-none");
        });
    }

    // Genel düzenleme fonksiyonu
    function makeEditable(inputClass, textClass, saveCallback) {
        $(document).on("click", textClass, function () {
            var currentText = $(this).text();
            $(this).addClass('d-none');
            $(this).siblings(inputClass).removeClass('d-none').val(currentText).focus();
        });

        $(document).on("blur", inputClass, function () {
            var newText = $(this).val();
            $(this).addClass('d-none');
            $(this).siblings(textClass).removeClass('d-none').text(newText);
            if (saveCallback) saveCallback(newText);
        });
    }

    // Seçenek düzenleme fonksiyonu
    function makeSelectEditable(selectClass, textClass) {
        $(document).on("click", textClass, function () {
            $(this).addClass('d-none');
            $(this).siblings(selectClass).removeClass('d-none');
        });

        $(document).on("change", selectClass, function () {
            var textElement = $(this).prev(textClass);
            textElement.text($(this).find(":selected").text());
            $(this).addClass("d-none");
            textElement.removeClass("d-none");
        });
    }

    // Menüleri açıp kapama işlemi
    [".lokasyon-select", ".alt-kategori-select", ".paket-select", ".uretici-select", ".tedarikci-select"].forEach(function (selectClass) {
        toggleMenu(selectClass, selectClass.replace("select", "text"));
    });

    // Menülere dışarıdan tıklayınca kapanma işlemi
    $(document).on("click", function (event) {
        var selectors = ".lokasyon-text, .lokasyon-select, .alt-kategori-text, .alt-kategori-select, .paket-text, .paket-select, .uretici-text, .uretici-select, .tedarikci-text, .tedarikci-select";
        if (!$(event.target).closest(selectors).length) {
            $(".lokasyon-select, .alt-kategori-select, .paket-select, .uretici-select, .tedarikci-select").addClass("d-none");
            $(".lokasyon-text, .alt-kategori-text, .paket-text, .uretici-text, .tedarikci-text").removeClass("d-none");
        }
    });

    // Metin düzenleme
    makeEditable('.komponent-ad-input', '.komponent-ad-text');
    makeEditable('.ek-bilgi-input', '.ek-bilgi-text');
    makeEditable('.adet-input', '.adet-text');

    // Seçim menüleri için düzenleme
    [".tedarikci-select", ".uretici-select", ".alt-kategori-select", ".lokasyon-select", ".paket-select"].forEach(function (selectClass) {
        makeSelectEditable(selectClass, selectClass.replace("select", "text"));
    });

    // Veri güncellenmesi (Enter tuşu veya blur ile)
    $(document).on("blur keyup", ".komponent-ad-input, .ek-bilgi-input, .alt-kategori-select, .tedarikci-select, .uretici-select, .lokasyon-select, .paket-select, .adet-input", function (event) {
        if (event.type === "keyup" && event.keyCode !== 13) {
            return;
        }

        var row = $(this).closest("tr");
        var komponentId = row.data("komponent-id");

        var updatedData = {
            komponent_id: komponentId,
            komponent_ad: row.find(".komponent-ad-input").val(),
            ek_bilgi: row.find(".ek-bilgi-input").val(),
            kategori_id: row.find(".alt-kategori-select").val(),
            tedarikci_id: row.find(".tedarikci-select").val(),
            uretici_id: row.find(".uretici-select").val(),
            lokasyon_id: row.find(".lokasyon-select").val(),
            paket_id: row.find(".paket-select").val(),
            adet_id: row.find(".adet-input").val()
        };

        // Güncelleme işlemi
        updateData(updatedData, row);
    });

    // Veriyi güncelleme için genel AJAX fonksiyonu
    function updateData(updatedData, row) {
        $.ajax({
            url: 'komponent-guncelle.php',
            type: 'POST',
            data: updatedData,
            success: function (response) {
                var data = JSON.parse(response);
                console.log(data);  // Gelen veriyi konsola yazdır

                if (data.status === 'success') {
                    updateRowText(row, data.data);
                } else {
                    alert(data.message);
                }
            },
            error: function (xhr, status, error) {
                console.error("Ajax Hatası: " + error);
                alert("Bir hata oluştu.");
            }
        });
    }

    // Satır metinlerini güncelle
    function updateRowText(row, data) {
        row.find(".komponent-ad-text").text(data.komponent_ad);
        row.find(".ek-bilgi-text").text(data.ek_bilgi);
        row.find(".alt-kategori-text").text(data.tam_kategori);
        row.find(".kategori-text").text(data.kategori);
        row.find(".tedarikci-text").text(data.tedarikci_ad);
        row.find(".uretici-text").text(data.uretici_ad);
        row.find(".lokasyon-text").text(data.tam_lokasyon);
        row.find(".paket-text").text(data.tam_paket);
        row.find(".adet-text").text(data.adet);


        var komponentId2 = row.data("komponent-id");
        var yeniKomponentAd = data.komponent_ad;  // Yeni komponent adı
        var yeniEkBilgi = data.ek_bilgi;  // Yeni ek bilgi

        // "komponent_ad" select öğesini güncelle
        $('select[name="komponent_adSelect"]').each(function() {
            var selectElement = $(this);

            selectElement.find('option').each(function() {
                var optionValue = $(this).val();  // option'ın value değerini al
                if (optionValue == komponentId2) {
                    $(this).text(yeniKomponentAd);  // Option öğesinin metnini güncelle
                }
            });
        });

// "ek_bilgi" select öğesini güncelle
        $('select[name="ek_bilgiSelect"]').each(function() {
            var selectElement = $(this);

            selectElement.find('option').each(function() {
                var optionValue = $(this).val();  // option'ın value değerini al
                if (optionValue == komponentId2) {
                    $(this).text(yeniEkBilgi);  // Option öğesinin metnini güncelle
                }
            });
        });

    }

// Komponent silme işlemi
    $(document).on("click", ".delete-btn", function (e) {
        var row = $(this).closest("tr");
        var komponentId = row.data("komponent-id");

        if (confirm("Bu komponenti silmek istediğinizden emin misin?")) {
            $.ajax({
                url: "delete.php",
                method: "POST",
                data: {komponent_id: komponentId},
                success: function (response) {
                    var res = JSON.parse(response);
                    if (res.success) {
                        // Silinen komponenti tablo satırından kaldır
                        row.remove();
                        alert(res.message);

                        // "komponent_ad" select öğesindeki option'ları güncelle
                        $('select[name="komponent_adSelect"]').each(function() {
                            var selectElement = $(this);

                            selectElement.find('option').each(function() {
                                var optionValue = $(this).val();  // option'ın value değerini al
                                if (optionValue == komponentId) {
                                    $(this).remove();  // Silinen komponentin option öğesini kaldır
                                }
                            });
                        });

                        // "ek_bilgi" select öğesindeki option'ları güncelle
                        $('select[name="ek_bilgiSelect"]').each(function() {
                            var selectElement = $(this);

                            selectElement.find('option').each(function() {
                                var optionValue = $(this).val();  // option'ın value değerini al
                                if (optionValue == komponentId) {
                                    $(this).remove();  // Silinen komponentin option öğesini kaldır
                                }
                            });
                        });

                    } else {
                        alert(res.message);
                    }
                },
                error: function () {
                    alert("Bir hata oluştu, lütfen tekrar deneyin.");
                }
            });
        }
        e.preventDefault();
    });


    $(document).on("click", ".view-btn", function () {
        var row = $(this).closest("tr");
        var componentId = row.data("komponent-id");

        $.ajax({
            url: "komponent_modal_cek.php",
            method: "GET",
            data: { id: componentId },
            success: function (response) {
                console.log(response); // JSON çıktısını kontrol et

                // JSON ise parse etmeye gerek yok, direk objeyse parse etme!
                var data = typeof response === "string" ? JSON.parse(response) : response;

                var modalContent = '';

                if (data.error) {
                    modalContent = `<p>${data.error}</p>`;
                } else {
                    // Başlık güncellemesi
                    var ek_bilgi = data.component.ek_bilgi || 'Ek Bilgi Bulunamadı';
                    var komponentAd = data.component.komponent_ad || 'Komponent Adı Bulunamadı';
                    document.getElementById('myModalLabel').innerText = komponentAd + ' > ' + ek_bilgi;

                    var imageContent = data.component.gorsel
                        ? `<div class="image-container">
                            <img src="${data.component.gorsel}" alt="Görsel" class="img-fluid" />
                         </div>`
                        : '';

                    var fileContent = '';
                    data.files.forEach(function (filePath, index) {
                        var fileName = filePath.split('/').pop();
                        fileContent += `
                            <div class="pdf-container">
                                <embed id="pdf-${index}" src="${filePath}" type="application/pdf" width="100%" height="600px">
                                <div class="pdf-info">
                                    <span>${fileName}</span>
                                    <button class="btn btn-sm btn-primary fullscreen-btn" data-pdf-url="${filePath}">Tam Ekran</button>
                                </div>
                            </div>
                        `;
                    });

                    modalContent = `
                   <div class="row">
                    <div class="col-md-12">
                        <div class="accordion" id="accordionExample">
                            <div class="accordion-item">
                                <h2 class="accordion-header">
                                    <button class="accordion-button" type="button" data-bs-toggle="collapse" data-bs-target="#collapseOne">
                                        Bilgiler
                                    </button>
                                </h2>
                                <div id="collapseOne" class="accordion-collapse collapse show">
                                    <div class="accordion-body">
                                        <div class="text-content">
                                            <div class="media-container">
                                                ${imageContent}
                                                ${fileContent}
                                            </div>
                                            <p><strong>Ad:</strong> ${data.component.komponent_ad}</p>
                                            <p><strong>Ek Bilgi:</strong> ${data.component.ek_bilgi}</p>
                                            <p><strong>Kategori:</strong> ${data.component.tam_kategori}</p>
                                            <p><strong>Üretici:</strong> ${data.component.uretici_ad}</p>
                                            <p><strong>Tedarikçi:</strong> ${data.component.tedarikci_ad}</p>
                                            <p><strong>Paket:</strong> ${data.component.tam_paket}</p>
                                            <p><strong>Lokasyon:</strong> ${data.component.tam_lokasyon}</p>
                                            <p><strong>Adet:</strong> ${data.component.adet}</p>

                                        </div>
                                    </div>
                                </div>
                            </div>
                            <div class="accordion-item">
                                <h2 class="accordion-header">
                                    <button class="accordion-button collapsed" type="button" data-bs-toggle="collapse" data-bs-target="#collapseTwo">
                                        Ayrıntılar
                                    </button>
                                </h2>
                                <div id="collapseTwo" class="accordion-collapse collapse">
                                    <div class="accordion-body">
                                        ${data.component.detaylar}
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                    `;

                    // Modal içeriğini güncelle
                    $("#modalContent").html(modalContent);
                    $("#myModal").modal("show");

                    // PDF butonları için event listener
                    $(document).on("click", ".fullscreen-btn", function () {
                        var pdfUrl = $(this).data("pdf-url");
                        window.open(pdfUrl, "_blank");
                    });
                }
            },
            error: function () {
                alert("Veri alırken bir hata oluştu.");
            }
        });
    });




});
