<?php
require_once 'inc/guvenlik.php';

function sanitize_input($data) {
    return htmlspecialchars(trim($data));
}

function check_user_permission() {
    if (!isset($_SESSION['eposta'])) {
        header('Location: index.php');
        exit();
    }
}

check_user_permission();

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $komponentId = sanitize_input($_POST['KomponentDuzenleID']);
    $komponentAd = sanitize_input($_POST['ad22']);
    $ekBilgi = sanitize_input($_POST['ek_bilgi2']);
    $kategoriId = sanitize_input($_POST['kategori2']);
    $tedarikciId = sanitize_input($_POST['tedarikci2']);
    $ureticiId = sanitize_input($_POST['uretici2']);
    $lokasyonId = sanitize_input($_POST['lokasyon2']);
    $paketId = sanitize_input($_POST['paket2']);
    $adetId = sanitize_input($_POST['adet2']);
    $detaylar = sanitize_input($_POST['detaylar']);

    try {
        $query = "
            UPDATE komponent
            SET ad = :komponent_ad, ek_bilgi = :ek_bilgi, kategori_id = :kategori_id,
                tedarikci_id = :tedarikci_id, uretici_id = :uretici_id, lokasyon_id = :lokasyon_id, 
                paket_id = :paket_id, adet = :adet_id, detaylar = :detaylar
            WHERE id = :komponent_id
        ";

        $stmt = $baglantim->prepare($query);
        $stmt->bindParam(':komponent_ad', $komponentAd, PDO::PARAM_STR);
        $stmt->bindParam(':ek_bilgi', $ekBilgi, PDO::PARAM_STR);
        $stmt->bindParam(':kategori_id', $kategoriId, PDO::PARAM_INT);
        $stmt->bindParam(':tedarikci_id', $tedarikciId, PDO::PARAM_INT);
        $stmt->bindParam(':uretici_id', $ureticiId, PDO::PARAM_INT);
        $stmt->bindParam(':lokasyon_id', $lokasyonId, PDO::PARAM_INT);
        $stmt->bindParam(':paket_id', $paketId, PDO::PARAM_INT);
        $stmt->bindParam(':adet_id', $adetId, PDO::PARAM_INT);
        $stmt->bindParam(':detaylar', $detaylar, PDO::PARAM_STR);
        $stmt->bindParam(':komponent_id', $komponentId, PDO::PARAM_INT);
        $stmt->execute();

        $cteQuery = $baglantim->prepare("
            WITH RECURSIVE cte_lokasyon AS (
                SELECT id, ad, lokasyon_id, 0 AS derinlik, ad AS tam_lokasyon
                FROM lokasyon WHERE lokasyon_id = 0  
                UNION ALL
                SELECT l.id, l.ad, l.lokasyon_id, cte_lokasyon.derinlik + 1, 
                       CONCAT(cte_lokasyon.tam_lokasyon, ' > ', l.ad)
                FROM lokasyon l
                JOIN cte_lokasyon ON cte_lokasyon.id = l.lokasyon_id
            ),
            cte_kategori AS (
                SELECT id, ad, kategori_id, 0 AS derinlik, ad AS tam_kategori
                FROM kategori WHERE kategori_id = 0  
                UNION ALL
                SELECT k.id, k.ad, k.kategori_id, cte_kategori.derinlik + 1, 
                       CONCAT(cte_kategori.tam_kategori, ' > ', k.ad)
                FROM kategori k
                JOIN cte_kategori ON cte_kategori.id = k.kategori_id
            ),
            cte_paket AS (
                SELECT id, ad, paket_id, 0 AS derinlik, ad AS tam_paket
                FROM paket WHERE paket_id = 0  
                UNION ALL
                SELECT p.id, p.ad, p.paket_id, cte_paket.derinlik + 1, 
                       CONCAT(cte_paket.tam_paket, ' > ', p.ad)
                FROM paket p
                JOIN cte_paket ON cte_paket.id = p.paket_id
            )
            SELECT 
                komp.id AS komponent_id, komp.ad AS komponent_ad, komp.ek_bilgi, komp.adet, komp.detaylar,
                cte_kategori.id AS kategori_id, cte_kategori.tam_kategori,
                cte_paket.id AS paket_id, cte_paket.tam_paket,
                cte_lokasyon.id AS lokasyon_id, cte_lokasyon.tam_lokasyon,
                uretici.id AS uretici_id, uretici.ad AS uretici_ad,
                tedarikci.id AS tedarikci_id, tedarikci.ad AS tedarikci_ad
            FROM komponent komp
            LEFT JOIN cte_kategori ON cte_kategori.id = komp.kategori_id
            LEFT JOIN cte_paket ON cte_paket.id = komp.paket_id
            LEFT JOIN cte_lokasyon ON cte_lokasyon.id = komp.lokasyon_id
            LEFT JOIN uretici ON uretici.id = komp.uretici_id
            LEFT JOIN tedarikci ON tedarikci.id = komp.tedarikci_id
            WHERE komp.id = :komponent_id
        ");

        $cteQuery->bindParam(':komponent_id', $komponentId, PDO::PARAM_INT);
        $cteQuery->execute();
        $sonuc = $cteQuery->fetch(PDO::FETCH_ASSOC);

        // Ajax ile post edilen verilere bilgi gönderir ve tablonun ilgili satırını sayfa yenilenmeden günceller
        echo json_encode([
            'success' => true,
            'message' => 'Başarıyla güncellendi!',
            'komponent_id' => $komponentId,  // Komponent ID'yi eklediğimizden emin olalım
            'updated_values' => [
                'komponent_ad' => $komponentAd,
                'ek_bilgi' => $ekBilgi,
                'kategori_id' => $kategoriId, // **Bunu eklediğinizden emin olun**
                'paket_id' => $paketId, // **Bunu eklediğinizden emin olun**
                'lokasyon_id' => $lokasyonId, // **Bunu eklediğinizden emin olun**
                'tam_kategori' => $sonuc['tam_kategori'] ?? 'Bilinmiyor',
                'tam_lokasyon' => $sonuc['tam_lokasyon'] ?? 'Bilinmiyor',
                'tedarikci_ad' => $sonuc['tedarikci_ad'] ?? 'Bilinmiyor',
                'uretici_ad' => $sonuc['uretici_ad'] ?? 'Bilinmiyor',
                'tedarikci_id' => $tedarikciId, // **Bunu eklediğinizden emin olun**
                'uretici_id' => $ureticiId, // **Bunu eklediğinizden emin olun**
                'tam_paket' => $sonuc['tam_paket'] ?? 'Bilinmiyor'
            ]
        ]);

    } catch (PDOException $e) {
        echo json_encode(['success' => false, 'message' => 'Hata oluştu.']);
        error_log('Database Error: ' . $e->getMessage());
    }
}
?>
