<?php
// Güvenlik kodlarını dahil et
require_once 'inc/guvenlik.php';

// Hiyerarşik kategori sorgusu
$query_kategori = "
WITH RECURSIVE kategori_hiyerarsi AS (
    SELECT id, kategori_id, ad,
    CAST(ad AS CHAR(200)) AS yol,
    0 AS seviye
    FROM kategori
    WHERE kategori_id = 0

    UNION ALL

    SELECT k.id, k.kategori_id,
    CONCAT(REPEAT(' - ', kh.seviye + 1), k.ad) AS ad,
    CONCAT(kh.yol, ' > ', k.ad) AS yol,
    kh.seviye + 1
    FROM kategori k
    INNER JOIN kategori_hiyerarsi kh ON k.kategori_id = kh.id
)
SELECT id, kategori_id, ad, yol
FROM kategori_hiyerarsi
ORDER BY yol;
";

$stmt_kategori = $baglantim->prepare($query_kategori);
$stmt_kategori->execute();
$kategoriler = $stmt_kategori->fetchAll(PDO::FETCH_ASSOC);

// Hiyerarşik paket sorgusu
$query_paket = "
WITH RECURSIVE paket_hiyerarsi AS (
    SELECT id, paket_id, ad,
    CAST(ad AS CHAR(200)) AS yol,
    0 AS seviye
    FROM paket
    WHERE paket_id = 0

    UNION ALL

    SELECT p.id, p.paket_id,
    CONCAT(REPEAT(' - ', ph.seviye + 1), p.ad) AS ad,
    CONCAT(ph.yol, ' > ', p.ad) AS yol,
    ph.seviye + 1
    FROM paket p
    INNER JOIN paket_hiyerarsi ph ON p.paket_id = ph.id
)
SELECT id, paket_id, ad, yol
FROM paket_hiyerarsi
ORDER BY yol;
";

$stmt_paket = $baglantim->prepare($query_paket);
$stmt_paket->execute();
$paketler = $stmt_paket->fetchAll(PDO::FETCH_ASSOC);

// Hiyerarşik lokasyon sorgusu
$query_lokasyon = "
WITH RECURSIVE lokasyon_hiyerarsi AS (
    SELECT id, lokasyon_id, ad,
    CAST(ad AS CHAR(200)) AS yol,
    0 AS seviye
    FROM lokasyon
    WHERE lokasyon_id = 0

    UNION ALL

    SELECT l.id, l.lokasyon_id,
    CONCAT(REPEAT(' - ', lh.seviye + 1), l.ad) AS ad,
    CONCAT(lh.yol, ' > ', l.ad) AS yol,
    lh.seviye + 1
    FROM lokasyon l
    INNER JOIN lokasyon_hiyerarsi lh ON l.lokasyon_id = lh.id
)
SELECT id, lokasyon_id, ad, yol
FROM lokasyon_hiyerarsi
ORDER BY yol;
";

$stmt_lokasyon = $baglantim->prepare($query_lokasyon);
$stmt_lokasyon->execute();
$lokasyonlar = $stmt_lokasyon->fetchAll(PDO::FETCH_ASSOC);

// Üretici sorgusu
$query_uretici = "SELECT * FROM uretici ORDER BY ad ASC";
$stmt_uretici = $baglantim->prepare($query_uretici);
$stmt_uretici->execute();
$ureticiler = $stmt_uretici->fetchAll(PDO::FETCH_ASSOC);

// Tedarikci sorgusu
$query_tedarikci = "SELECT * FROM tedarikci ORDER BY ad ASC";
$stmt_tedarikci = $baglantim->prepare($query_tedarikci);
$stmt_tedarikci->execute();
$tedarikciler = $stmt_tedarikci->fetchAll(PDO::FETCH_ASSOC);

// Komponent verilerini çekme
$query = "
WITH RECURSIVE cte_lokasyon AS (
    SELECT l.id AS lokasyon_id,
    COALESCE(NULLIF(l.ad, ''), '---') AS lokasyon_ad,
    l.lokasyon_id AS lokasyon_lokasyon_id,
    0 AS derinlik,
    COALESCE(NULLIF(l.ad, ''), '---') AS tam_lokasyon
    FROM lokasyon l
    WHERE l.lokasyon_id = 0

    UNION ALL

    SELECT l.id AS lokasyon_id,
    COALESCE(NULLIF(l.ad, ''), '---') AS lokasyon_ad,
    l.lokasyon_id AS lokasyon_lokasyon_id,
    cte_lokasyon.derinlik + 1 AS derinlik,
    CONCAT(cte_lokasyon.tam_lokasyon, ' > ', COALESCE(NULLIF(l.ad, ''), '---')) AS tam_lokasyon
    FROM lokasyon l
    JOIN cte_lokasyon ON cte_lokasyon.lokasyon_id = l.lokasyon_id
),
cte_kategori AS (
    SELECT k.id AS kategori_id,
    COALESCE(NULLIF(k.ad, ''), '---') AS kategori_ad,
    k.kategori_id AS kategori_kategori_id,
    0 AS derinlik,
    COALESCE(NULLIF(k.ad, ''), '---') AS tam_kategori
    FROM kategori k
    WHERE k.kategori_id = 0

    UNION ALL

    SELECT k.id AS kategori_id,
    COALESCE(NULLIF(k.ad, ''), '---') AS kategori_ad,
    k.kategori_id AS kategori_kategori_id,
    cte_kategori.derinlik + 1 AS derinlik,
    CONCAT(cte_kategori.tam_kategori, ' > ', COALESCE(NULLIF(k.ad, ''), '---')) AS tam_kategori
    FROM kategori k
    JOIN cte_kategori ON cte_kategori.kategori_id = k.kategori_id
),
cte_paket AS (
    SELECT p.id AS paket_id,
    COALESCE(NULLIF(p.ad, ''), '---') AS paket_ad,
    p.paket_id AS paket_paket_id,
    0 AS derinlik,
    COALESCE(NULLIF(p.ad, ''), '---') AS tam_paket
    FROM paket p
    WHERE p.paket_id = 0

    UNION ALL

    SELECT p.id AS paket_id,
    COALESCE(NULLIF(p.ad, ''), '---') AS paket_ad,
    p.paket_id AS paket_paket_id,
    cte_paket.derinlik + 1 AS derinlik,
    CONCAT(cte_paket.tam_paket, ' > ', COALESCE(NULLIF(p.ad, ''), '---')) AS tam_paket
    FROM paket p
    JOIN cte_paket ON cte_paket.paket_id = p.paket_id
)
SELECT
    COALESCE(NULLIF(cte_lokasyon.lokasyon_id, ''), '---') AS lokasyon_id,
    COALESCE(NULLIF(cte_lokasyon.lokasyon_ad, ''), '---') AS lokasyon_ad,
    COALESCE(NULLIF(cte_lokasyon.tam_lokasyon, ''), '---') AS tam_lokasyon,
    COALESCE(NULLIF(cte_kategori.kategori_id, ''), '---') AS kategori_id,
    COALESCE(NULLIF(cte_kategori.kategori_ad, ''), '---') AS kategori_ad,
    COALESCE(NULLIF(cte_kategori.tam_kategori, ''), '---') AS tam_kategori,
    COALESCE(NULLIF(cte_paket.paket_id, ''), '---') AS paket_id,
    COALESCE(NULLIF(cte_paket.paket_ad, ''), '---') AS paket_ad,
    COALESCE(NULLIF(cte_paket.tam_paket, ''), '---') AS tam_paket,
    COALESCE(NULLIF(komp.id, ''), '---') AS komponent_id,
    COALESCE(NULLIF(komp.ad, ''), '---') AS komponent_ad,
    COALESCE(NULLIF(komp.ek_bilgi, ''), '---') AS ek_bilgi,
    COALESCE(NULLIF(komp.adet, ''), '---') AS adet,
    COALESCE(NULLIF(uretici.id, ''), '---') AS uretici_id,
    COALESCE(NULLIF(uretici.ad, ''), '---') AS uretici_ad,
    COALESCE(NULLIF(tedarikci.id, ''), '---') AS tedarikci_id,
    COALESCE(NULLIF(tedarikci.ad, ''), '---') AS tedarikci_ad
FROM komponent komp
LEFT JOIN cte_lokasyon ON cte_lokasyon.lokasyon_id = komp.lokasyon_id
LEFT JOIN cte_kategori ON cte_kategori.kategori_id = komp.kategori_id
LEFT JOIN cte_paket ON cte_paket.paket_id = komp.paket_id
LEFT JOIN uretici ON uretici.id = komp.uretici_id
LEFT JOIN tedarikci ON tedarikci.id = komp.tedarikci_id
ORDER BY komp.id DESC;
";

$stmt = $baglantim->prepare($query);
$stmt->execute();
$components = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>
<style>
    /* Modal dialog için maksimum genişlik */
    .modal-dialog {
        max-width: 90%; /* Modal genişliğinin %90'ı kadar */
        width: 100%; /* Modal genişliği ekran genişliğine uyum sağlar */
        margin: 30px auto; /* Modal'ı ekranın ortasına hizalar */
    }

    /* Modal içeriği */
    .modal-content {
        width: 100%; /* İçeriğin tamamını kullanacak şekilde genişlet */
    }

    /* Modal Body */
    .modal-body {
        padding: 20px;
        word-wrap: break-word; /* Kelime kaymasını engeller */
        max-width: 100%; /* İçeriğin maksimum genişliğini ayarlayalım */
    }

    /* Flex düzeniyle görsel ve PDF'leri yan yana hizala */
    .media-container {
        display: flex; /* Flex düzeni ile öğeleri yan yana hizalar */
        gap: 10px; /* Görsel ile PDF arasında boşluk bırakır */
        flex-wrap: wrap; /* Taşmalar engellenir */
        margin-bottom: 20px; /* Öğeler arasında mesafe */
        width: 100%; /* Genişliği %100 yapar */
    }

    /* Görsel düzenlemeleri */
    .image-container {
        flex: 1; /* Görselin esnek genişliğe sahip olmasını sağlar */
        max-width: 48%; /* Görselin genişliği %48'i kadar olacak */
        width: 100%; /* Görselin genişliğini %100 yapar */
    }

    .image-container img {
        width: 100%; /* Görselin genişliğini container'ı kadar almasını sağlar */
        height: 200px; /* Yükseklik sabitlenir 200px */
        object-fit: cover; /* Görselin container'a uygun şekilde kesilmesini sağlar */
    }

    /* PDF container */
    .pdf-container {
        flex: 1; /* PDF'nin esnek genişliğe sahip olmasını sağlar */
        max-width: 48%; /* PDF'nin genişliği %48'i kadar olacak */
        width: 100%; /* PDF'nin genişliğini %100 yapar */
        margin-bottom: 20px; /* PDF ile içerik arasında boşluk bırakır */
    }

    /* PDF embed tam genişlikte */
    .pdf-container.embed-full {
        max-width: 100% !important; /* PDF'nin genişliğini %100 yapacak */
        width: 100% !important; /* PDF'nin genişliğini %100 yapacak */
    }

    /* PDF embed */
    .pdf-container embed {
        width: 100%; /* PDF'nin genişliğini container'ı kadar almasını sağlar */
        height: 200px; /* Sabit yükseklik 200px */
        border: none; /* Çerçeveyi kaldır */
        object-fit: contain; /* PDF içeriğini container'a sığdırır */
    }

    /* Metin içerikleri */
    .text-content p {
        text-align: justify;
        line-height: 1.5;
        margin-top: 0;
        margin-bottom: 10px;
    }

    /* Responsive Düzenlemeler */
    @media (max-width: 768px) {
        /* Mobil ekranlarda görsel ve PDF öğeleri alt alta yerleştirilecek */
        .media-container {
            flex-direction: column; /* Görsel ve PDF'yi dikey yerleştirir */
            align-items: center; /* Her ikisini de ortalar */
            width: 100%; /* 100% genişlik */
        }

        /* Görselin genişliği %100, alt alta olacak şekilde */
        .image-container, .pdf-container {
            max-width: 100%; /* %100 genişlik alır */
            width: 100%; /* %100 genişlik */
            margin-bottom: 20px; /* Öğeler arasındaki boşluk */
        }

        /* Görselin ve PDF'nin yüksekliği 200px sabit kalır */
        .image-container img,
        .pdf-container embed {
            height: 200px; /* Sabit yükseklik 200px */
        }
    }

    @media (max-width: 480px) {
        /* Daha küçük ekranlar için, metin boyutunu küçültüyoruz */
        .text-content p {
            font-size: 14px; /* Küçük ekranlarda daha küçük metin boyutu */
        }
    }

    /* PDF Bilgi ve Tam Ekran Butonu */
    .pdf-info {
        text-align: center;
        margin-top: 5px;
    }

    .pdf-info span {
        font-size: 14px;
        display: block;
        margin-bottom: 5px;
    }

    .pdf-info button {
        background-color: #007bff;
        color: white;
        border: none;
        padding: 5px 10px;
        cursor: pointer;
        border-radius: 5px;
        font-size: 14px;
    }

    .pdf-info button:hover {
        background-color: #0056b3;
    }

</style>

<style>
    /* Başlıkların seçilmesini engellemek */
    th {
        user-select: none; /* Başlıkların metin seçilmesini engeller */
        cursor: move; /* Başlıklar için pointer işareti */
        position: relative; /* Çarpı işaretinin doğru yerleştirilmesi için */
    }

    /* Sürüklenebilir alanlar için stil */
    th, td {
        cursor: move; /* Taşıma için işaretçi */
        transition: all 0.3s ease; /* Geçiş efekti */
    }

    /* Sürüklenen öğenin stilini belirleyelim */
    .dragging {
        opacity: 0.7; /* Saydamlık */
        background-color: #f9f9f9; /* Arka plan rengi */
        box-shadow: 0 0 15px rgba(0, 0, 0, 0.2); /* Hafif gölge */
        z-index: 999; /* Üstte görünmesi için */
        cursor: move; /* Sürükleniyor işareti */
    }

    /* Hedef sütunun üzerinde geldiğinde stil */
    .dragging-over {
        border-left: 3px solid #007bff; /* Hedef sütunun sol tarafında çizgi */
        background-color: #f0f8ff; /* Hedef sütunun arka planını değiştirme */
    }

    /* Hover efektleri */
    th:hover {
        background-color: #e3f2fd; /* Hover durumunda başlık arka planı */
        border-radius: 4px; /* Yuvarlatılmış köşeler */
        box-shadow: 0 2px 5px rgba(0, 123, 255, 0.2); /* Hover gölge */
    }

    /* Sütun başlığı üzerine gelindiğinde + işareti göster */
    th:hover::after {
        position: absolute;
        right: 10px; /* Çarpı işaretinin sağa yerleştirilmesi */
        top: 50%; /* Yükseklik merkezine yerleştirilmesi */
        transform: translateY(-50%); /* Dikey ortalamayı sağla */
        font-size: 18px;
        color: #007bff; /* Mavi renk */
    }

    /* Kolayca sürüklenebilmesi için geniş alan */
    .draggable-cell {
        cursor: grab; /* Tüm hücreyi sürüklenebilir yap */
    }

    /* Tabloyu sarmalayan kutu */
    #tablom {
        width: 100%;
        border-collapse: collapse;
    }

    /* Tablo başlığı ve hücreleri için stil */
    th, td {
        padding: 10px;
        border: 1px solid #ddd;
        text-align: center;
    }

    /* td üzerinde pointer işareti */
    td {
        cursor: pointer; /* Hücrelere tıklandığında pointer işareti */
    }

    /* Şeritli (striped) tablo stilini ekle */
    #tablom tbody tr:nth-child(odd) {
        background-color: #f2f2f2; /* Gri tonları (odd satırlar) */
    }

    #tablom tbody tr:nth-child(even) {
        background-color: #ffffff; /* Beyaz (even satırlar) */
    }

    #tablom th:first-child, #tablom th:last-child {
        cursor: default;
    }

    table#tablom tbody tr:hover {
        background-color: #fff79f !important;
    }
</style>

<style>
    .highlight {
        background-color: yellow;
        font-weight: bold;
        padding: 0;
        border-radius: 3px;
    }
</style>
<style>
    /* Genel sayfalama stil */
    .pagination {
        display: flex;
        justify-content: center;
        align-items: center;
        padding: 8px;
        gap: 6px;
    }

    /* Sayfa butonları */
    .page-btn {
        padding: 6px 12px; /* Butonları küçültüyoruz */
        font-size: 12px; /* Yazı boyutunu küçültüyoruz */
        background-color: #f5f5f5;
        border: 1px solid #ccc;
        border-radius: 4px;
        cursor: pointer;
        transition: background-color 0.3s;
    }

    .page-btn:hover {
        background-color: #ddd;
    }

    .page-btn:disabled {
        background-color: #f0f0f0;
        cursor: not-allowed;
    }

    /* Sayfa numaraları */
    .page-numbers {
        display: flex;
        gap: 4px;
    }

    .page-numbers .page-num {
        padding: 4px 8px; /* Sayfa numarası butonlarını küçültüyoruz */
        font-size: 12px; /* Yazı boyutunu küçültüyoruz */
        background-color: #f5f5f5;
        border: 1px solid #ccc;
        border-radius: 4px;
        cursor: pointer;
        transition: background-color 0.3s;
    }

    .page-numbers .page-num:hover {
        background-color: #ddd;
    }

    .page-numbers .active {
        background-color: #007bff;
        color: white;
        font-weight: bold;
    }

    /* Modal içindeki tüm text alanlarının font-size'ını değiştirme */
    .modal-body {
        font-size: 16px; /* İstediğiniz boyutu buraya yazabilirsiniz */
    }

    /* Modal başlığının font-size'ını değiştirme */
    .modal-title {
        font-size: 20px; /* İstediğiniz boyutu buraya yazabilirsiniz */
    }

    /* Modal içindeki paragrafların font-size'ını değiştirme */
    .modal-body p {
        font-size: 14px; /* İstediğiniz boyutu buraya yazabilirsiniz */
    }
</style>

<style>
    th {
        cursor: pointer;
        position: relative;
    }

    .sort-arrow {
        position: absolute;
        right: 10px;
        top: 50%;
        transform: translateY(-50%);
        width: 0;
        height: 0;
        border-left: 5px solid transparent;
        border-right: 5px solid transparent;
        border-top: 5px solid #000;
        opacity: 0.5;
        visibility: hidden; /* Başlangıçta oklar gizli */
    }

    th .asc {
        border-top: 6px solid #000; /* Artan sıralama ok */
        visibility: visible; /* Artan sıralama ok simgesi görünür */
    }

    th .desc {
        border-bottom: 6px solid #000; /* Azalan sıralama ok */
        visibility: visible; /* Azalan sıralama ok simgesi görünür */
    }

    .sort-arrow.asc {
        border-top: none;
        border-bottom: 5px solid #000;
    }

    .sort-arrow.desc {
        border-top: 5px solid #000;
        border-bottom: none;
    }

    th:hover .sort-arrow {
        opacity: 1;
    }
</style>
<style>
    #tablom th,
    #tablom td {
        text-align: left;
    }

</style>

<style>
    #tablom th:first-child, #tablom td:first-child {
        min-width: 10px; /* Minimum genişlik */
    }

</style>
<style>
    /* Style for the toggle switch */
    .switch {
        position: relative;
        display: inline-block;
        width: 34px; /* Smaller width for the toggle */
        height: 18px; /* Smaller height for the toggle */
        margin: 14px 40px 14px 0; /* Space between toggles */
    }

    .switch input {
        opacity: 0;
        width: 0;
        height: 0;
    }

    .slider {
        position: absolute;
        cursor: pointer;
        top: 0;
        left: 0;
        right: 0;
        bottom: 0;
        background-color: #ccc;
        transition: .4s;
        border-radius: 50px;
    }

    .slider:before {
        position: absolute;
        content: "";
        height: 12px; /* Smaller slider */
        width: 12px; /* Smaller slider */
        border-radius: 50%;
        left: 3px; /* Center the slider */
        bottom: 3px; /* Center the slider */
        background-color: white;
        transition: .4s;
    }

    input:checked + .slider {
        background-color: #4CAF50; /* Green background when toggled */
    }

    input:checked + .slider:before {
        transform: translateX(16px); /* Move the slider to the right */
    }

    /* Style for the labels (optional, can make them smaller) */
    .label {
        font-size: 12px; /* Smaller font size for the labels */
        margin-top: 5px; /* Space between toggle and label */
        visibility: visible; /* Hide the label by default */
        position: absolute;
        top: -25px; /* Position the label above the toggle */
        left: 50%;
        transform: translateX(-50%); /* Center the label horizontally */
        white-space: nowrap; /* Ensure the text doesn't break */
        opacity: 1;
        transition: opacity 0.3s ease, visibility 0.3s ease;
    }


    .switch:hover .slider {
        border: 1px solid #aaa; /* Optional: add border on hover */
    }


</style>

<div class="column-switches">
    <label class="switch">
        <input type="checkbox" class="column-toggle" data-column="0" checked/>
        <span class="slider"></span>
        <span class="label">#</span>
    </label>
    <label class="switch">
        <input type="checkbox" class="column-toggle" data-column="1" checked/>
        <span class="slider"></span>
        <span class="label">Ad</span>
    </label>
    <label class="switch">
        <input type="checkbox" class="column-toggle" data-column="2" checked/>
        <span class="slider"></span>
        <span class="label">Ek Bilgi</span>
    </label>
    <label class="switch">
        <input type="checkbox" class="column-toggle" data-column="3" checked/>
        <span class="slider"></span>
        <span class="label">Üst Kategori</span>
    </label>
    <label class="switch">
        <input type="checkbox" class="column-toggle" data-column="4" checked/>
        <span class="slider"></span>
        <span class="label">Tam Kategori</span>
    </label>
    <label class="switch">
        <input type="checkbox" class="column-toggle" data-column="5" checked/>
        <span class="slider"></span>
        <span class="label">Üretici</span>
    </label>
    <label class="switch">
        <input type="checkbox" class="column-toggle" data-column="6" checked/>
        <span class="slider"></span>
        <span class="label">Tedarikçi</span>
    </label>
    <label class="switch">
        <input type="checkbox" class="column-toggle" data-column="7" checked/>
        <span class="slider"></span>
        <span class="label">Paket</span>
    </label>
    <label class="switch">
        <input type="checkbox" class="column-toggle" data-column="8" checked/>
        <span class="slider"></span>
        <span class="label">Lokasyon</span>
    </label>
    <label class="switch">
        <input type="checkbox" class="column-toggle" data-column="9" checked/>
        <span class="slider"></span>
        <span class="label">Adet</span>
    </label>
    <label class="switch">
        <input type="checkbox" class="column-toggle" data-column="10" checked/>
        <span class="slider"></span>
        <span class="label">İşlemler</span>
    </label>
</div>

<!-- Arama Kutusu -->
<div class="d-flex mb-3">
    <select id="recordLimit" class="form-select w-auto me-2">
        <option class="space-option" value="5" selected>5 Kayıt göster</option>
        <option class="space-option" value="10">10 Kayıt göster</option>
        <option class="space-option" value="50">50 Kayıt göster</option>
        <option class="space-option" value="100">100 Kayıt göster</option>
    </select>
    <input type="text" id="customSearch" class="form-control w-auto" placeholder="Ara...">
    <button id="clearSearch" class="btn btn-outline-secondary ms-2">Temizle</button>

    <!-- Toggle Switch'ler -->

</div>

<table id="tablom" style="width: 100%;">
    <thead>
    <tr>
        <th>#</th> <!-- Sıra numarası -->
        <th>Ad<span class="sort-arrow"></span></th>
        <th>Ek Bilgi<span class="sort-arrow"></span></th>
        <th>Üst Kategori<span class="sort-arrow"></span></th>
        <th>Tam Kategori<span class="sort-arrow"></span></th>
        <th>Üretici<span class="sort-arrow"></span></th>
        <th>Tedarikçi<span class="sort-arrow"></span></th>
        <th>Paket<span class="sort-arrow"></span></th>
        <th>Lokasyon<span class="sort-arrow"></span></th>
        <th>Adet<span class="sort-arrow"></span></th>
        <th>İşlemler</th>
    </tr>
    </thead>


    <tfoot>
    <tr>
        <th>#</th> <!-- Sıra numarası -->
        <th>Ad
            <select name="komponent_adSelect" class="form-select">
                <option value="">Seçiniz</option>
                <?php foreach ($components as $row): ?>
                    <option value="<?= $row['komponent_id'] ?>">
                        <?= htmlspecialchars($row['komponent_ad']) ?>
                    </option>
                <?php endforeach; ?>
            </select>
        </th>
        <th>Ek Bilgi
            <select name="ek_bilgiSelect" class="form-select">
                <option value="">Seçiniz</option>
                <?php foreach ($components as $row): ?>
                    <option value="<?= $row['komponent_id'] ?>">
                        <?= htmlspecialchars($row['ek_bilgi']) ?>
                    </option>
                <?php endforeach; ?>
            </select>
        </th>
        <th>Üst Kategori
            <select class="form-select">
                <option value="">Seçiniz</option>
                <?php
                // Benzersiz kategori isimlerini tutacak bir dizi
                $benzersizKategoriler = [];

                // Kategoriler üzerinde döngü başlatıyoruz
                foreach ($kategoriler as $kat) {
                    // Kategori yolunu explode ile bölelim ve ilk kısmı alalım
                    $ilkKisim = htmlspecialchars(trim(explode('>', $kat['yol'])[0]));

                    // Eğer bu kategori adı daha önce eklenmediyse, diziye ekleyelim
                    if (!in_array($ilkKisim, $benzersizKategoriler)) {
                        $benzersizKategoriler[] = $ilkKisim;  // İlk kısmı benzersiz listeye ekliyoruz
                        ?>
                        <option value="<?= $kat['id'] ?>">
                            <?= $ilkKisim ?>
                        </option>
                        <?php
                    }
                }
                ?>
            </select>
        </th>
        <th>Tam Kategori
            <select class="form-select">
                <option value="">Seçiniz</option>
                <?php foreach ($kategoriler as $kat): ?>
                    <option value="<?= $kat['id'] ?>">
                        <?= htmlspecialchars($kat['yol']) ?>
                    </option>
                <?php endforeach; ?>
            </select>
        </th>
        <th>Üretici
            <select class="form-select">
                <option value="">Seçiniz</option>
                <?php foreach ($ureticiler as $uretici): ?>
                    <option value="<?= $uretici['id'] ?>">
                        <?= htmlspecialchars($uretici['ad']) ?>
                    </option>
                <?php endforeach; ?>
            </select>
        </th>
        <th>Tedarikçi
            <select class="form-select">
                <option value="">Seçiniz</option>
                <?php foreach ($tedarikciler as $tedarikci): ?>
                    <option value="<?= $tedarikci['id'] ?>">
                        <?= htmlspecialchars($tedarikci['ad']) ?>
                    </option>
                <?php endforeach; ?>
            </select>
        </th>
        <th>Paket
            <select class="form-select">
                <option value="">Seçiniz</option>
                <?php
                // Benzersiz kategori isimlerini tutacak bir dizi
                $benzersizKategoriler = [];

                // Kategoriler üzerinde döngü başlatıyoruz
                foreach ($paketler as $kat) {
                    // Kategori yolunu explode ile bölelim ve ilk kısmı alalım
                    $ilkKisim = htmlspecialchars($kat['yol']);

                    // Eğer bu kategori adı daha önce eklenmediyse, diziye ekleyelim
                    if (!in_array($ilkKisim, $benzersizKategoriler)) {
                        $benzersizKategoriler[] = $ilkKisim;  // İlk kısmı benzersiz listeye ekliyoruz
                        ?>
                        <option value="<?= $kat['id'] ?>">
                            <?= $ilkKisim ?>
                        </option>
                        <?php
                    }
                }
                ?>
            </select>
        </th>
        <th>Lokasyon
            <span class="lokasyon-text"></span>


            <select class="form-select">
                <option value="">Seçiniz</option>
                <?php
                // Benzersiz kategori isimlerini tutacak bir dizi
                $benzersizKategoriler = [];

                // Kategoriler üzerinde döngü başlatıyoruz
                foreach ($lokasyonlar as $kat) {
                    // Kategori yolunu explode ile bölelim ve ilk kısmı alalım
                    $ilkKisim = htmlspecialchars($kat['yol']);

                    // Eğer bu kategori adı daha önce eklenmediyse, diziye ekleyelim
                    if (!in_array($ilkKisim, $benzersizKategoriler)) {
                        $benzersizKategoriler[] = $ilkKisim;  // İlk kısmı benzersiz listeye ekliyoruz
                        ?>
                        <option value="<?= $kat['id'] ?>">
                            <?= $ilkKisim ?>
                        </option>
                        <?php
                    }
                }
                ?>
            </select>
        </th>
        <th>Adet</th>
        <th>İşlemler</th>
    </tr>
    </tfoot>


    <tbody>
    <?php $rowNumber = 1; // Başlangıçta sıra numarası ?>
    <?php foreach ($components as &$row): ?>
        <tr data-komponent-id="<?= htmlspecialchars($row['komponent_id']) ?>">
            <td><?= $rowNumber++ ?></td> <!-- Sıra numarası buraya eklendi -->

            <td>
                <span class="komponent-ad-text"><?= htmlspecialchars($row['komponent_ad']) ?></span>
                <input type="text" class="form-control komponent-ad-input d-none"
                       value="<?= htmlspecialchars($row['komponent_ad']) ?>">
            </td>

            <td>
                <span class="ek-bilgi-text"><?= htmlspecialchars($row['ek_bilgi']) ?></span>
                <input type="text" class="form-control ek-bilgi-input d-none"
                       value="<?= htmlspecialchars($row['ek_bilgi']) ?>">
            </td>

            <td>
                <span class="kategori-text"><?= htmlspecialchars(explode('>', $row['tam_kategori'])[0]) ?></span>
            </td>

            <td>
                <span class="alt-kategori-text"><?= htmlspecialchars($row['tam_kategori']) ?></span>
                <select class="form-select alt-kategori-select d-none">
                    <?php foreach ($kategoriler as $kat): ?>
                        <option value="<?= $kat['id'] ?>" <?= ($kat['id'] == $row['kategori_id']) ? 'selected' : '' ?>>
                            <?= htmlspecialchars($kat['ad']) ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </td>

            <td>
                <span class="uretici-text"><?= htmlspecialchars($row['uretici_ad']) ?></span>
                <select class="form-select uretici-select d-none">
                    <?php foreach ($ureticiler as $uretici): ?>
                        <option value="<?= $uretici['id'] ?>" <?= ($uretici['id'] == $row['uretici_id']) ? 'selected' : '' ?>>
                            <?= htmlspecialchars($uretici['ad']) ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </td>

            <td>
                <span class="tedarikci-text"><?= htmlspecialchars($row['tedarikci_ad']) ?></span>
                <select class="form-select tedarikci-select d-none">
                    <?php foreach ($tedarikciler as $tedarikci): ?>
                        <option value="<?= $tedarikci['id'] ?>" <?= ($tedarikci['id'] == $row['tedarikci_id']) ? 'selected' : '' ?>>
                            <?= htmlspecialchars($tedarikci['ad']) ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </td>

            <td>
                <span class="paket-text"><?= htmlspecialchars($row['tam_paket']) ?></span>
                <select class="form-select paket-select d-none">
                    <?php foreach ($paketler as $kat): ?>
                        <option value="<?= $kat['id'] ?>" <?= ($kat['id'] == $row['paket_id']) ? 'selected' : '' ?>>
                            <?= htmlspecialchars($kat['ad']) ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </td>

            <td>
                <span class="lokasyon-text"><?= htmlspecialchars($row['tam_lokasyon']) ?></span>
                <select class="form-select lokasyon-select d-none">
                    <?php foreach ($lokasyonlar as $lokasyon): ?>
                        <option value="<?= $lokasyon['id'] ?>" <?= ($lokasyon['id'] == $row['lokasyon_id']) ? 'selected' : '' ?>>
                            <?= htmlspecialchars($lokasyon['ad']) ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </td>

            <td>
                <span class="adet-text"><?= htmlspecialchars($row['adet']) ?></span>
                <input type="text" class="form-control adet-input d-none"
                       value="<?= htmlspecialchars($row['adet']) ?>">
            </td>

            <td>
                <button class="btn btn-outline-secondary btn-sm view-btn m-1" data-bs-toggle="modal"
                        data-bs-target="#myModal">Gözat
                </button>
                <button class="btn btn-outline-primary btn-sm update-btn m-1"
                        data-bs-toggle="modal"
                        data-bs-target="#duzenleModal"
                        data-id="<?php echo htmlspecialchars($row['komponent_id']); ?>"
                        data-url="komponent-duzenle-formu.php?KomponentDuzenleID=<?php echo htmlspecialchars($row['komponent_id']); ?>">
                    Düzenle
                </button>

                <button class="btn btn-outline-danger btn-sm delete-btn m-1">Sil</button>
            </td>
        </tr>
    <?php endforeach; ?>
    </tbody>
</table>

<div id="pagination" class="pagination">
    <button class="page-btn" id="firstPage">&laquo; İlk</button>
    <div id="pageNumbers" class="page-numbers"></div>
    <button class="page-btn" id="lastPage">Son &raquo;</button>
</div>
<!-- Detay Modal HTML -->
<div class="modal fade" id="myModal" tabindex="-1" aria-labelledby="myModalLabel" aria-hidden="true">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="myModalLabel">Komponent Detayları</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <!-- Modal Body -->
            <div class="modal-body" id="modalContent">
            </div>

            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Kapat</button>
            </div>
        </div>
    </div>
</div>
<!-- Detay Modal HTML -->


<!-- Düzenleme Modalı -->
<div class="modal fade" id="duzenleModal" tabindex="-1" aria-labelledby="duzenleModalLabel" aria-hidden="true">
    <div class="modal-dialog modal-lg">
        <div class="modal-content">
            <div id="responseMessage" class="alert" style="display:none;"></div> <!-- Success mesajı burada -->

            <div class="modal-header">
                <h5 class="modal-title" id="duzenleModalLabel">Ürün Düzenle</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Kapat"></button>
            </div>
            <div class="modal-body">

                <!-- Buraya AJAX ile form yüklenecek -->
            </div>
        </div>
    </div>
</div>
<script>
    $(document).ready(function () {
        // Edit butonuna tıklanınca formu yükleyin
        $(".update-btn").click(function () {
            var url = $(this).data("url"); // Butondan URL al
            $("#duzenleModal .modal-body").html('<div class="text-center"><span class="spinner-border spinner-border-sm"></span> Yükleniyor...</div>');

            $.ajax({
                url: url,
                type: "GET",
                success: function (response) {
                    //console.log('Form yüklendi:', response); // Debug mesajı
                    $("#duzenleModal .modal-body").html(response); // Modal içine formu yükle
                    $('#duzenleModal').modal('show'); // Modal'ı aç
                },
                error: function (xhr, status, error) {
                    console.log('Form yüklenirken hata oluştu:', error); // Hata mesajını konsola yazdır
                    $("#duzenleModal .modal-body").html('<div class="alert alert-danger">Form yüklenirken hata oluştu.</div>');
                }
            });
        });
    });
</script>


<script>
    $(document).ready(function () {
        var allRows = $('#tablom tbody tr'); // Tüm kayıtları al
        var visibleRows = parseInt($('#recordLimit option:selected').val()); // recordLimit, select elementinin id'si
        var filteredRows = allRows; // Başlangıçta tüm satırlar görünür
        var currentPage = 1; // Başlangıçta 1. sayfa
        var totalPages = Math.ceil(filteredRows.length / visibleRows); // Toplam sayfa sayısı
        var lastSelectedOption = null; // Seçilen select menüsünü hatırlamak için değişken

        var sortedColumnIndex = -1; // Başlangıçta sıralama yapılmamış
        var sortOrder = 'asc'; // Varsayılan sıralama yönü: artan
        var clickCount = 0; // Tıklama sayısını takip etmek için bir sayaç

/// Sütun başlıklarına tıklama işlemi ekliyoruz
        $('#tablom thead th').click(function () {
            var index = $(this).index(); // Tıklanan sütunun index'ini alıyoruz
            clickCount++; // Tıklama sayacını artırıyoruz

            // İlk olarak sayfayı 1. sayfaya dönüyoruz
            currentPage = 1;

            if (sortedColumnIndex === index) {
                if (clickCount === 3) {
                    // 3. tıklama olduğunda varsayılan sıralama durumuna dönüyoruz
                    sortedColumnIndex = -1; // Başlangıçta sıralama yapılmamış
                    sortOrder = 'asc'; // Varsayılan sıralama yönü: artan
                    clickCount = 0; // Sayaç sıfırlanır
                } else {
                    // 1. ve 2. tıklama durumlarında sıralama yönü tersine döner
                    sortOrder = sortOrder === 'asc' ? 'desc' : 'asc';
                }
            } else {
                // Yeni bir sütun seçilirse, sıralama index'ini güncelliyoruz
                sortedColumnIndex = index;
                sortOrder = 'asc'; // Varsayılan olarak artan sıralama
                clickCount = 1; // Sayaç 1'e ayarlanır
            }

            updateTable(); // Sıralama değiştiği için tabloyu güncelliyoruz
        });

        function updateTable() {
            // Görünmesi gereken kayıtları sayfaya sınırlıyoruz
            var startIndex = (currentPage - 1) * visibleRows;
            var endIndex = startIndex + visibleRows;

            // Burada sıralama işlemi yapılacak, tüm satırlar sıralandıktan sonra sayfalama uygulanacak
            var rowsToDisplay = filteredRows.slice().sort(function (a, b) {
                // Eğer sıralama yapılmadıysa veya varsayılan sıralama durumu varsa, sıralama yapılmaz
                if (sortedColumnIndex === -1) return 0;

                var cellB = $(a).find('td').eq(sortedColumnIndex).text().toLowerCase();
                var cellA = $(b).find('td').eq(sortedColumnIndex).text().toLowerCase();

                if (cellA > cellB) return sortOrder === 'asc' ? 1 : -1;
                if (cellA < cellB) return sortOrder === 'asc' ? -1 : 1;
                return 0;
            });

            // Sayfa başına sıralanmış satırları alıyoruz
            rowsToDisplay = rowsToDisplay.slice(startIndex, endIndex);

            $('#tablom tbody tr').hide(); // İlk önce tüm satırları gizleyelim

            // Sadece sıralanmış ve sayfa başına uygun satırları gösteriyoruz
            $(rowsToDisplay).toArray().forEach(function (row) {
                $(row).show(); // Sadece sıralanmış ve sayfa başına uygun satırları göster
            });

            // Satır numaralarını güncelle
            $('#tablom tbody tr').each(function (index) {
                var row = $(this);
                if (row.is(':visible')) {
                    var visibleIndex = (currentPage - 1) * visibleRows + $('#tablom tbody tr:visible').index(row) + 1;
                    row.find('td:first').text(visibleIndex); // İlk hücreye satır numarasını yaz
                }
            });

            updatePagination(); // Sayfalama butonlarını güncelle
        }




        function updatePagination() {
            totalPages = Math.ceil(filteredRows.length / visibleRows); // Toplam sayfa sayısını güncelle
            $('#pageNumbers').empty(); // Önceki sayfa numaralarını temizle

            var startPage = Math.max(currentPage - 1, 1);
            var endPage = Math.min(currentPage + 1, totalPages);

            if (totalPages > 1) {
                if (startPage > 1) {
                    $('#pageNumbers').append('<button class="page-num" data-page="1">1</button><span>...</span>');
                }

                for (var i = startPage; i <= endPage; i++) {
                    var pageButton = $('<button class="page-num" data-page="' + i + '">' + i + '</button>');
                    if (i === currentPage) pageButton.addClass('active');
                    $('#pageNumbers').append(pageButton);
                }

                if (endPage < totalPages) {
                    $('#pageNumbers').append('<span>...</span><button class="page-num" data-page="' + totalPages + '">' + totalPages + '</button>');
                }
            }

            $('#firstPage').prop('disabled', currentPage === 1);
            $('#lastPage').prop('disabled', currentPage === totalPages);

            $('.page-num').on('click', function () {
                currentPage = $(this).data('page');
                updateTable();
            });

            $('#lastPage, #firstPage').on('click', function () {
                currentPage = $(this).attr('id') === 'firstPage' ? 1 : totalPages;
                updateTable();
            });
        }

        $('#recordLimit').on('change', function () {
            visibleRows = parseInt($(this).val());
            currentPage = 1;
            updatePagination();
            updateTable();
        });


        // Arama kutusu (key up) işlemi
        $('#customSearch').on('keyup', function () {
            var value = $(this).val().toLowerCase();

            // Önceden yapılmış vurgulamayı kaldır
            $('#tablom td span.highlight').each(function () {
                var originalText = $(this).text();
                $(this).replaceWith(originalText);
            });

            // Eğer arama kutusu boşsa, son seçilen select menüsüne göre listeyi yeniden filtrele
            if (value === '') {
                // Eğer backspace ile silme yapılmışsa, son seçilen select menüsüne göre filtreleme yapalım
                if (lastSelectedOption) {
                    const selectedSelect = $('#tablom tfoot select.form-select').filter(function () {
                        return this.options[this.selectedIndex].text === lastSelectedOption;
                    }).get(0);

                    if (selectedSelect) {
                        filterRowsBasedOnSelect(selectedSelect);
                    } else {
                        allRows.show();
                        filteredRows = allRows;
                        currentPage = 1;
                        updatePagination();
                        updateTable();
                    }
                } else {
                    allRows.show();
                    filteredRows = allRows;
                    currentPage = 1;
                    updatePagination();
                    updateTable();
                }
                return;
            }

            // Eğer arama kutusu doluysa, sadece filtrelenmiş satırlarda arama yapalım
            var rowsToSearch = filteredRows;  // Filtrelenmiş satırlarda arama yap

            rowsToSearch = rowsToSearch.filter(function () {
                var match = false;
                var row = $(this);
                row.find('td span').each(function () {
                    var originalText = $(this).text();
                    var text = originalText.toLowerCase();

                    if (text.indexOf(value) > -1) {
                        match = true;
                        var regex = new RegExp('(' + escapeRegExp(value) + ')', 'gi');
                        var highlightedText = originalText.replace(regex, '<span class="highlight">$1</span>');
                        $(this).html(highlightedText);
                    }
                });
                return match;
            });

            // Arama sonrası sadece uygun satırları göster
            allRows.hide();
            rowsToSearch.show();
            filteredRows = rowsToSearch;  // Filtrelenen satırları güncelle
            currentPage = 1;
            updatePagination();
            updateTable();
        });

// Arama kutusunu temizleme (clearSearch)
        $('#clearSearch').on('click', function () {
            $('#customSearch').val('');
            $('#tablom td span.highlight').each(function () {
                var originalText = $(this).text();
                $(this).replaceWith(originalText);
            });

            // Arama kutusu temizlendiğinde, son seçilen select menüsüne göre listeyi yeniden filtrele
            if (lastSelectedOption) {
                const selectedSelect = $('#tablom tfoot select.form-select').filter(function () {
                    return this.options[this.selectedIndex].text === lastSelectedOption;
                }).get(0);

                if (selectedSelect) {
                    filterRowsBasedOnSelect(selectedSelect);
                } else {
                    allRows.show();
                    filteredRows = allRows;
                    currentPage = 1;
                    updatePagination();
                    updateTable();
                }
            } else {
                allRows.show();
                filteredRows = allRows;
                currentPage = 1;
                updatePagination();
                updateTable();
            }
        });

// Select menüsündeki değişiklikleri takip etme
        $('#tablom tfoot select.form-select').on('change', function (event) {
            const selectedOption = this.options[this.selectedIndex].text;  // Seçilen option'ı al
            lastSelectedOption = selectedOption;  // Son seçilen option'ı kaydet

            // Diğer select menülerindeki seçimleri sıfırlıyoruz
            $('#tablom tfoot select.form-select').each(function () {
                if (this !== event.target) {
                    this.selectedIndex = 0;
                }
            });

            // Seçilen option'a göre filtreleme yapalım
            filterRowsBasedOnSelect(event.target);  // Değişiklik yapan select elemanını parametre olarak geçiyoruz
        });

// Select menüsüne göre sadece ilgili sütunu filtreleme fonksiyonu
        // Select menüsüne göre sadece ilgili sütunu filtreleme fonksiyonu
        function filterRowsBasedOnSelect(selectElement) {
            const selectedOption = lastSelectedOption;
            const columnIndex = $(selectElement).closest('th').index(); // İlgili sütun indeksini al

            // Tüm highlight sınıflarını kaldırıyoruz
            $('#tablom td span').each(function () {
                var originalText = $(this).attr('data-original-text') || $(this).text();
                $(this).html(originalText); // Eski haline döndür
            });

            // "Seçiniz" veya boş seçim yapıldıysa, tüm satırları göster
            if (selectedOption === "Seçiniz" || !selectedOption) {
                allRows.show();
                filteredRows = allRows;
                updatePagination();
                updateTable();
                return;
            }

            // Seçilen option'a göre sadece ilgili sütundaki satırları filtreleyelim
            var rowsToShow = allRows.filter(function () {
                var match = false;
                var row = $(this);
                var cell = row.find('td').eq(columnIndex);  // İlgili sütundaki hücreyi al

                // Sadece span etiketlerini dikkate al
                var spans = cell.find('span');
                spans.each(function () {
                    var originalText = $(this).attr('data-original-text') || $(this).text(); // Orijinal metni al
                    var lowerCaseText = originalText.toLowerCase();

                    // Seçilen metinle eşleşme kontrolü (tam eşleşme)
                    if (lowerCaseText.includes(selectedOption.toLowerCase())) {
                        match = true;

                        // Metni vurgulama işlemi
                        var regex = new RegExp('(' + escapeRegExp(selectedOption) + ')', 'gi'); // Vurgulama için regex oluştur
                        var highlightedText = originalText.replace(regex, '<span class="highlight">$1</span>'); // Vurgulama işlemi

                        // Orijinal metni sakla ve vurgulamayı uygula
                        $(this).attr('data-original-text', originalText);
                        $(this).html(highlightedText);
                    }
                });

                return match;
            });

            // Diğer satırları gizleyip sadece uygun olanları göster
            allRows.hide();
            rowsToShow.show();
            filteredRows = rowsToShow;  // Filtrelenmiş satırları kaydet
            currentPage = 1;
            updatePagination();
            updateTable();
        }

// **Özel karakterleri doğru kaçış karakterine dönüştüren yardımcı fonksiyon**
        function escapeRegExp(string) {
            return string.replace(/[.*+?^${}()|[\]\\]/g, '\\$&'); // Özel karakterleri koruma
        }


// Özel karakterlere karşı RegExp güvenliği için yardımcı fonksiyon
        function escapeRegExp(string) {
            return string.replace(/[.*+?^=!:${}()|\[\]\/\\]/g, '\\$&');
        }


        var draggingIndex = -1;
        var draggedColumn = null;
        var isDragging = false;
        var dragTimeout = null;  // Gecikmeli taşıma için bir değişken
        var delay = 2000; // 2 saniye gecikme (2000 ms)

// Sayfa yüklendiğinde sütun sırasını ve görünürlük durumlarını geri yükleyelim
        function loadColumnState() {
            var columnOrder = JSON.parse(localStorage.getItem('columnOrder'));
            if (columnOrder) {
            } else {
                // Eğer sıralama kaydı yoksa, varsayılan sıralamayı al
                console.log('Sıralama kaydı yok!');
            }

            // Diğer görünürlük işlemleri burada devam eder...

            // Sütun görünürlüklerini load etmek
            $('#tablom th, #tablom tfoot th').each(function () {
                var columnIndex = $(this).data('column-index');
                var columnVisible = localStorage.getItem('column-' + columnIndex);

                // Eğer localStorage'da veri yoksa, varsayılan olarak 'true' (on) kabul et
                if (columnVisible === null) {
                    columnVisible = 'true';
                    localStorage.setItem('column-' + columnIndex, columnVisible); // Varsayılan olarak kaydet
                }

                // Switch konumunu geri yükle
                $('.column-toggle[data-column="' + columnIndex + '"]').prop('checked', columnVisible === 'true');

                $(this).css('display', columnVisible === 'true' ? 'table-cell' : 'none');

                // td'leri de gizle/göster
                $('#tablom td').each(function () {
                    if ($(this).hasClass('column-' + columnIndex)) {
                        $(this).css('display', columnVisible === 'true' ? 'table-cell' : 'none');
                    }
                });

                // select öğeleri için görünürlük kontrolü
                $('#tablom select').each(function () {
                    if ($(this).closest('th').hasClass('column-' + columnIndex)) {
                        $(this).closest('th').css('display', columnVisible === 'true' ? 'table-cell' : 'none');
                    }
                });
            });
        }

        // Sayfa yüklendiğinde sütun sırası ve görünürlüklerini geri yükle
        $(document).ready(function () {
            loadColumnState();
        });



        $('#tablom th, #tablom tfoot th').each(function (index) {
            $(this).attr('data-column-index', index);
            $(this).addClass('column-' + index);
        });

        $('#tablom tbody tr').each(function () {
            $(this).find('td').each(function (index) {
                $(this).addClass('column-' + index);
            });
        });

        $('#tablom th, #tablom tfoot th').on('mousedown', function (e) {
            var index = $(this).index();
            draggingIndex = index;
            draggedColumn = $(this);

            // Mouse tıklamasıyla taşıma başlatmadan önce 2 saniye bekleyelim
            dragTimeout = setTimeout(function () {
                isDragging = true;

                // Sadece taşıma işlemi başlatalım
                $('#tablom th, #tablom td, #tablom tfoot th').filter(function () {
                    return $(this).index() === draggingIndex;
                }).addClass('dragging');
            }, delay); // 2 saniye gecikme süresi

            $(document).on('mousemove', function (e) {
                if (!isDragging) return;

                var mouseX = e.pageX;
                var mouseY = e.pageY;

                $('#tablom th, #tablom td, #tablom tfoot th').each(function () {
                    var column = $(this);
                    var offset = column.offset();
                    var width = column.outerWidth();
                    var height = column.outerHeight();

                    if (mouseX >= offset.left && mouseX <= (offset.left + width) &&
                        mouseY >= offset.top && mouseY <= (offset.top + height)) {
                        column.addClass('dragging-over');
                    } else {
                        column.removeClass('dragging-over');
                    }
                });
            });

            $(document).on('mouseup', function () {
                // Eğer taşıma başladıysa, işlemi sonlandır
                if (isDragging) {
                    var targetColumn = $('.dragging-over').first();
                    if (targetColumn.length > 0 && targetColumn.index() !== draggingIndex) {
                        swapColumns(draggingIndex, targetColumn.index());
                    }

                    $('#tablom th, #tablom td, #tablom tfoot th').removeClass('dragging dragging-over');
                    $(document).off('mousemove mouseup');
                    isDragging = false;

                }

                // Eğer taşıma işlemi başlamadıysa, zamanlayıcıyı temizle
                clearTimeout(dragTimeout);
            });
        });


        // Sütunları takas yapma fonksiyonu
        function swapColumns(fromIndex, toIndex) {
            var table = $('#tablom');
            var rows = table.find('tr');
            var cols = table.find('tr').first().find('th');
            var footCols = table.find('tfoot tr').first().find('th');

            // İlk ve son sütunları engellemek için kontrol
            if (fromIndex === 0 || fromIndex === cols.length - 1 || toIndex === 0 || toIndex === cols.length - 1) {
                return; // İlk veya son sütun taşınamaz
            }

            // Sütunları sağa veya sola taşıma
            if (fromIndex > toIndex) {
                $(cols[fromIndex]).insertBefore(cols[toIndex]);
                $(footCols[fromIndex]).insertBefore(footCols[toIndex]);
            } else {
                $(cols[fromIndex]).insertAfter(cols[toIndex]);
                $(footCols[fromIndex]).insertAfter(footCols[toIndex]);
            }

            // Satırlardaki hücreleri güncelleme (td)
            rows.each(function () {
                var cells = $(this).find('td');
                var fromCell = $(cells[fromIndex]);
                var toCell = $(cells[toIndex]);

                if (fromIndex > toIndex) {
                    fromCell.insertBefore(toCell);
                } else {
                    fromCell.insertAfter(toCell);
                }
            });

            // Yeni sıralamayı localStorage'a kaydet
            saveColumnOrder();
        }

// Sütun sırasını localStorage'a kaydetme
        function saveColumnOrder() {
            var columnOrder = [];
            $('#tablom th').each(function () {
                var index = $(this).attr('data-column-index'); // `th`'nin index değeri
                if (index) {
                    columnOrder.push(parseInt(index)); // Index'leri array'e ekle
                }
            });

            // Tablodaki tüm satırlardaki `td` hücrelerini kaydet
            var rowOrders = [];
            $('#tablom tbody tr').each(function () {
                var cellOrder = [];
                $(this).find('td').each(function () {
                    var className = $(this).attr('class'); // `td` için class al
                    var match = className.match(/column-(\d+)/); // column-X içindeki rakamı al
                    if (match) {
                        cellOrder.push(parseInt(match[1])); // column-X'lerdeki sayıyı al
                    }
                });
                rowOrders.push(cellOrder);
            });

            localStorage.setItem('columnOrder', JSON.stringify(columnOrder));
            localStorage.setItem('rowOrders', JSON.stringify(rowOrders));
        }

// Sayfa yüklendiğinde sütun sırasını localStorage'den çekme ve uygulama
        function loadColumnOrder() {
            var columnOrder = JSON.parse(localStorage.getItem('columnOrder')) || [];
            var rowOrders = JSON.parse(localStorage.getItem('rowOrders')) || [];

            var table = $('#tablom');
            var ths = table.find('tr').first().find('th');  // Başlık hücreleri
            var footCols = table.find('tfoot tr').first().find('th');  // Footer hücreleri

            if (columnOrder.length > 0) {
                // 1. Başlık hücrelerini sırasına göre yerleştirme
                columnOrder.forEach(function (index) {
                    var thToMove = ths.filter('[data-column-index="' + index + '"]');
                    thToMove.detach().appendTo(ths.parent());
                });

                // 2. Satırlardaki (td) hücreleri sırasına göre yerleştirme
                var rows = table.find('tbody tr');
                rows.each(function (i) {
                    var cells = $(this).find('td');
                    var rowOrder = rowOrders[i];

                    rowOrder.forEach(function (index) {
                        var tdToMove = cells.filter('.column-' + index);
                        tdToMove.detach().appendTo(cells.parent());
                    });
                });

                // 3. Footer hücrelerini sırasına göre yerleştirme
                footCols.each(function (i) {
                    var footToMove = footCols.filter('[data-column-index="' + columnOrder[i] + '"]');
                    footToMove.detach().appendTo(footCols.parent());
                });
            }
        }

// Sayfa yüklendiğinde sıralama işlemini uygulamak için
        $(document).ready(function () {
            loadColumnOrder();  // Sayfa yüklendiğinde sütunları localStorage'den sırasına göre yerleştir
        });









        function updateSwitchColumnIndex() {
            $('#tablom th, #tablom tfoot th').each(function (index) {
                var columnIndex = index;
                $('.column-toggle[data-column="' + columnIndex + '"]').data('column', columnIndex);
            });
        }

        function updateThClass() {
            $('#tablom th, #tablom tfoot th').each(function (index) {
                var th = $(this);
                th.removeClass().addClass('column-' + index);
            });

            // Sütun başlıklarını da gizleme/gösterme fonksiyonunu ekleyelim
            $('.column-toggle').each(function () {
                var columnIndex = $(this).data('column');
                var columnVisible = $(this).prop('checked');

                // th, tfoot ve select öğelerini kontrol et
                $('#tablom th, #tablom tfoot th').each(function () {
                    if ($(this).hasClass('column-' + columnIndex)) {
                        $(this).css('display', columnVisible ? 'table-cell' : 'none');
                    }
                });

                // select öğelerinin görünürlüğünü de ayarla
                $('#tablom select').each(function () {
                    if ($(this).closest('th').hasClass('column-' + columnIndex)) {
                        $(this).closest('th').css('display', columnVisible ? 'table-cell' : 'none');
                    }
                });
            });
        }

        $('.column-toggle').on('change', function () {
            var columnIndex = $(this).data('column');
            var columnVisible = $(this).prop('checked');

            // LocalStorage'a kaydet
            localStorage.setItem('column-' + columnIndex, columnVisible);

            // Tablodaki başlıkları ve tfoot öğelerini gizle/göster
            $('#tablom th, #tablom tfoot th').each(function () {
                if ($(this).hasClass('column-' + columnIndex)) {
                    $(this).css('display', columnVisible ? 'table-cell' : 'none');
                }
            });

            $('#tablom td').each(function () {
                if ($(this).hasClass('column-' + columnIndex)) {
                    $(this).css('display', columnVisible ? 'table-cell' : 'none');
                }
            });

            // select öğeleri için görünürlük kontrolü
            $('#tablom select').each(function () {
                if ($(this).closest('th').hasClass('column-' + columnIndex)) {
                    $(this).closest('th').css('display', columnVisible ? 'table-cell' : 'none');
                }
            });
        });

// `tfoot th` öğelerinin gizlenmesi için ek bir düzenleme
        $('#tablom tfoot th').each(function (index) {
            $(this).attr('data-column-index', index);
            $(this).addClass('column-' + index);
        });

        updatePagination(); // Sayfalama butonlarını oluştur
        updateTable(); // Sayfayı güncelle



    });




    document.addEventListener('DOMContentLoaded', function () {
        const table = document.getElementById('tablom');
        const ths = table.querySelectorAll('th');
        let sortDirection = Array(ths.length).fill(null);  // Varsayılan sıralama durumu (null: varsayılan, 0: artan, 1: azalan)
        const originalData = Array.from(table.querySelectorAll('tbody tr'));  // Orijinal veri sırası

        // Başlıkları tıklama olayları ekle
        ths.forEach((th, index) => {
            if (index === 10) return; // İşlemler kolonunda sıralama yapılmasın

            th.addEventListener('click', () => {
                sortTable(index);
            });
        });

        function sortTable(columnIndex) {
            const rows = Array.from(table.querySelectorAll('tbody tr'));

            // Sıralama yönünü değiştir
            let newDirection;
            if (sortDirection[columnIndex] === null) {
                newDirection = 1;  // İlk başta azalan sıralama
            } else if (sortDirection[columnIndex] === 1) {
                newDirection = 0;  // Azalan'dan artana
            } else {
                newDirection = null;  // Artan'dan varsayılan duruma dön
            }

            sortDirection[columnIndex] = newDirection;

            // Diğer okları temizle
            ths.forEach((th, i) => {
                if (i !== columnIndex) {
                    const otherArrow = th.querySelector('.sort-arrow');
                    if (otherArrow) {
                        otherArrow.classList.remove('asc', 'desc');
                        otherArrow.style.visibility = 'hidden';  // Ok simgesini gizle
                    }
                }
            });

            // Seçilen başlık için ok simgesini güncelle
            updateArrow(columnIndex, newDirection);

            if (newDirection === null) {
                resetSorting(); // Varsayılan duruma dön
                // Varsayılan sıralama numarasını 1, 2, 3, 4, 5 olarak güncelle
                updateRowNumbers(null);
                return;
            }

            const sortedRows = rows.sort((a, b) => {
                const aText = a.cells[columnIndex].innerText.trim();
                const bText = b.cells[columnIndex].innerText.trim();

                const aValue = parseValue(aText);
                const bValue = parseValue(bText);

                if (typeof aValue === 'number' && typeof bValue === 'number') {
                    return newDirection === 0 ? aValue - bValue : bValue - aValue;
                } else if (typeof aValue === 'string' && typeof bValue === 'string') {
                    return newDirection === 0 ? aValue.localeCompare(bValue) : bValue.localeCompare(aValue);
                } else {
                    // Sayı ve metin karışık durumunda:
                    return newDirection === 0 ? aText.localeCompare(bText) : bText.localeCompare(aText);
                }
            });

            // tbody'yi sıralanmış satırlara göre yeniden düzenle
            const tbody = table.querySelector('tbody');
            sortedRows.forEach(row => tbody.appendChild(row));

            // Satır numaralarını güncelle
            updateRowNumbers(newDirection);
        }


        // Satır numaralarını güncelleyen fonksiyon
        function updateRowNumbers(direction) {
            const rows = $('#tablom tbody tr:visible');
            rows.each(function (index) {
                const row = $(this);
                let rowNumber;

                // Varsayılan sıralama durumunda 1, 2, 3, 4, 5 sırası
                if (direction === null) {
                    rowNumber = index + 1;  // Varsayılan sıralama
                }
                // ASC için 1,2,3... DESC için 5,4,3...
                else if (direction === 0) {
                    rowNumber = index + 1;  // Artan sıralama
                } else {
                    rowNumber = rows.length - index;  // Azalan sıralama
                }

                row.find('td:first').text(rowNumber);  // Satır numarasını güncelle
            });
        }

        // Ok simgesini güncelleme fonksiyonu
        function updateArrow(columnIndex, direction) {
            const arrowSpan = ths[columnIndex].querySelector('.sort-arrow');
            if (arrowSpan) {
                arrowSpan.style.visibility = 'visible';  // Ok simgesini görünür yap

                // Sıralama yönüne göre ok simgesini ayarla
                if (direction === 0) {
                    arrowSpan.classList.add('asc');
                    arrowSpan.classList.remove('desc');
                } else if (direction === 1) {
                    arrowSpan.classList.add('desc');
                    arrowSpan.classList.remove('asc');
                } else {
                    arrowSpan.classList.remove('asc', 'desc');
                    arrowSpan.style.visibility = 'hidden';  // Ok simgesini gizle
                }
            }
        }


        // Varsayılan sıralamaya geri dönme fonksiyonu
        function resetSorting() {
            const tbody = table.querySelector('tbody');
            tbody.innerHTML = '';  // tbody'yi temizle

            // Orijinal veriyi sıralamadan geri ekle
            originalData.forEach((row, index) => {
                tbody.appendChild(row);
            });

            ths.forEach(th => {
                const arrowSpan = th.querySelector('.sort-arrow');
                if (arrowSpan) {
                    arrowSpan.classList.remove('asc', 'desc');  // Ok simgelerini kaldır
                    arrowSpan.style.visibility = 'hidden';  // Ok simgesini gizle
                }
            });
        }

        // Sayısal ve metin türündeki veriyi analiz edip sayısal değere dönüştüren fonksiyon
        function parseValue(value) {
            // Matematiksel ifadeleri sayıya dönüştür
            try {
                const numericValue = eval(value);
                if (!isNaN(numericValue)) {
                    return numericValue;
                }
            } catch (e) {
                // Eğer değer geçerli bir matematiksel ifade değilse, metin olarak bırak
            }

            // Eğer matematiksel bir ifade değilse, metin olarak dön
            return value;
        }

        // Sayısal veri kontrolü fonksiyonu
        function isColumnNumeric(rows, columnIndex) {
            const text = rows[0].cells[columnIndex].innerText.trim();
            // Hücredeki metni sayıya dönüştürüp geçerli bir sayı olup olmadığını kontrol ediyoruz
            return !isNaN(parseFloat(text));
        }
    });

</script>


<!-- bu kodları elleme -->
<script>
    $(document).ready(function () {
        // Her sütunun genişliğini ayarlamak için fonksiyon
        function adjustColumnWidths() {
            var maxWidths = [];
            var minWidth = 1; // İlk sütunun minimum genişliği (isteğe bağlı olarak değiştirebilirsiniz)

            // İlk sütunun genişliğini hemen ayarla
            $('#tablom thead th:first-child').css('width', minWidth + 'px');
            $('#tablom tbody td:first-child').css('width', minWidth + 'px');
            $('#tablom tfoot th:first-child').css('width', minWidth + 'px');

            // Her sütunun en geniş hücresini bul
            $('#tablom thead th').each(function (colIndex) {
                var maxWidth = 0;

                // Her sütunun tüm satırlarındaki hücrelerin genişliklerini kontrol et
                $('#tablom tbody tr').each(function () {
                    var cell = $(this).find('td').eq(colIndex);
                    var cellWidth = cell.outerWidth();
                    maxWidth = Math.max(maxWidth, cellWidth);
                });

                // Başlık hücresinin genişliğini de dahil et
                var headerCellWidth = $(this).outerWidth();
                maxWidth = Math.max(maxWidth, headerCellWidth);

                // Tfoot başlık hücresinin genişliğini de dahil et
                var footerCellWidth = $('#tablom tfoot th').eq(colIndex).outerWidth();
                maxWidth = Math.max(maxWidth, footerCellWidth);

                // Bu sütun için en geniş genişliği sakla
                maxWidths.push(maxWidth);
            });

            // Tüm sütunlar için genişlikleri ayarla (thead ve tfoot için)
            $('#tablom thead th').each(function (colIndex) {
                if (colIndex === 0) {
                    $(this).css('width', minWidth + 'px');
                } else {
                    $(this).css('width', maxWidths[colIndex] + 'px');
                }
            });

            $('#tablom tfoot th').each(function (colIndex) {
                if (colIndex === 0) {
                    $(this).css('width', minWidth + 'px');
                } else {
                    $(this).css('width', maxWidths[colIndex] + 'px');
                }
            });

            // Tüm tbody hücrelerinin genişliklerini ayarla
            $('#tablom tbody td').each(function () {
                var colIndex = $(this).index();
                if (colIndex === 0) {
                    $(this).css('width', minWidth + 'px');
                } else {
                    $(this).css('width', maxWidths[colIndex] + 'px');
                }
            });
        }

        // Sayfa yüklendiğinde genişlikleri ayarla
        adjustColumnWidths();

        // Sayfa boyutu değiştiğinde sütunları yeniden ayarla
        $(window).resize(function () {
            adjustColumnWidths(); // Sayfa boyutu değiştiğinde sütunları yeniden ayarla
        });
    });

</script>
<script>
    // "space-option" sınıfına sahip option elemanını seçiyoruz
    const option = document.querySelector('.space-option');

    // Metnin sonuna ekstra boşluk ekliyoruz
    option.innerHTML = option.innerHTML + '\u00A0\u00A0\u00A0\u00A0\u00A0\u00A0\u00A0\u00A0';  // İki adet non-breaking space
</script>
<script src="js/komponent-listele-javascript.js"></script>
<!-- bu kodları elleme -->
