<?php
require_once 'inc/guvenlik.php';

try {
    $baglantim->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    // GET isteği ile gelen ID'yi al
    $id = isset($_GET['id']) ? (int)$_GET['id'] : 0;

    // SQL sorgusunu yaz
    $sql = "
    WITH RECURSIVE cte_lokasyon AS (
        SELECT l.id AS lokasyon_id, 
               COALESCE(NULLIF(l.ad, ''), '---') AS lokasyon_ad, 
               l.lokasyon_id AS lokasyon_lokasyon_id, 
               0 AS derinlik,
               COALESCE(NULLIF(l.ad, ''), '---') AS tam_lokasyon
        FROM lokasyon l
        WHERE l.lokasyon_id = 0  

        UNION ALL

        SELECT l.id AS lokasyon_id, 
               COALESCE(NULLIF(l.ad, ''), '---') AS lokasyon_ad, 
               l.lokasyon_id AS lokasyon_lokasyon_id, 
               cte_lokasyon.derinlik + 1 AS derinlik,
               CONCAT(cte_lokasyon.tam_lokasyon, ' > ', COALESCE(NULLIF(l.ad, ''), '---')) AS tam_lokasyon
        FROM lokasyon l
        JOIN cte_lokasyon ON cte_lokasyon.lokasyon_id = l.lokasyon_id  
    ),
    cte_kategori AS (
        SELECT k.id AS kategori_id, 
               COALESCE(NULLIF(k.ad, ''), '---') AS kategori_ad, 
               k.kategori_id AS kategori_kategori_id, 
               0 AS derinlik,
               COALESCE(NULLIF(k.ad, ''), '---') AS tam_kategori
        FROM kategori k
        WHERE k.kategori_id = 0  

        UNION ALL

        SELECT k.id AS kategori_id, 
               COALESCE(NULLIF(k.ad, ''), '---') AS kategori_ad, 
               k.kategori_id AS kategori_kategori_id, 
               cte_kategori.derinlik + 1 AS derinlik,
               CONCAT(cte_kategori.tam_kategori, ' > ', COALESCE(NULLIF(k.ad, ''), '---')) AS tam_kategori
        FROM kategori k
        JOIN cte_kategori ON cte_kategori.kategori_id = k.kategori_id  
    ),
    cte_paket AS (
        SELECT p.id AS paket_id, 
               COALESCE(NULLIF(p.ad, ''), '---') AS paket_ad, 
               p.paket_id AS paket_paket_id, 
               0 AS derinlik,
               COALESCE(NULLIF(p.ad, ''), '---') AS tam_paket
        FROM paket p
        WHERE p.paket_id = 0  

        UNION ALL

        SELECT p.id AS paket_id, 
               COALESCE(NULLIF(p.ad, ''), '---') AS paket_ad, 
               p.paket_id AS paket_paket_id, 
               cte_paket.derinlik + 1 AS derinlik,
               CONCAT(cte_paket.tam_paket, ' > ', COALESCE(NULLIF(p.ad, ''), '---')) AS tam_paket
        FROM paket p
        JOIN cte_paket ON cte_paket.paket_id = p.paket_id  
    )
    SELECT 
        COALESCE(NULLIF(cte_lokasyon.lokasyon_id, ''), '---') AS lokasyon_id,
        COALESCE(NULLIF(cte_lokasyon.lokasyon_ad, ''), '---') AS lokasyon_ad,
        COALESCE(NULLIF(cte_lokasyon.tam_lokasyon, ''), '---') AS tam_lokasyon,
        COALESCE(NULLIF(cte_kategori.kategori_id, ''), '---') AS kategori_id,
        COALESCE(NULLIF(cte_kategori.kategori_ad, ''), '---') AS kategori_ad,
        COALESCE(NULLIF(cte_kategori.tam_kategori, ''), '---') AS tam_kategori,
        COALESCE(NULLIF(cte_paket.paket_id, ''), '---') AS paket_id,
        COALESCE(NULLIF(cte_paket.paket_ad, ''), '---') AS paket_ad,
        COALESCE(NULLIF(cte_paket.tam_paket, ''), '---') AS tam_paket,
        COALESCE(NULLIF(komp.id, ''), '---') AS komponent_id,
        COALESCE(NULLIF(komp.ad, ''), '---') AS komponent_ad,
        COALESCE(NULLIF(komp.ek_bilgi, ''), '---') AS ek_bilgi,
        COALESCE(NULLIF(komp.adet, ''), '---') AS adet,
        COALESCE(NULLIF(komp.dosyalar, ''), '---') AS dosyalar,
        COALESCE(NULLIF(komp.detaylar, ''), '---') AS detaylar,
        COALESCE(NULLIF(uretici.id, ''), '---') AS uretici_id,
        COALESCE(NULLIF(uretici.ad, ''), '---') AS uretici_ad,
        COALESCE(NULLIF(tedarikci.id, ''), '---') AS tedarikci_id,
        COALESCE(NULLIF(tedarikci.ad, ''), '---') AS tedarikci_ad
    FROM komponent komp
    LEFT JOIN cte_lokasyon ON cte_lokasyon.lokasyon_id = komp.lokasyon_id
    LEFT JOIN cte_kategori ON cte_kategori.kategori_id = komp.kategori_id
    LEFT JOIN cte_paket ON cte_paket.paket_id = komp.paket_id
    LEFT JOIN uretici ON uretici.id = komp.uretici_id
    LEFT JOIN tedarikci ON tedarikci.id = komp.tedarikci_id
    WHERE komp.id = :detayID
    ORDER BY komp.id DESC
    ";

    // Prepare SQL statement
    $stmt = $baglantim->prepare($sql);
    $stmt->bindParam(':detayID', $id, PDO::PARAM_INT);
    $stmt->execute();

    // Veriyi çek
    $data = $stmt->fetch(PDO::FETCH_ASSOC);

    // Eğer veri bulunduysa
    if ($data) {
        // XSS önlemi için HTML karakterlerini güvenli bir şekilde dönüştür
        $data['detaylar'] = html_entity_decode($data['detaylar'],  ENT_QUOTES, 'UTF-8');

        // Dosya ID'lerini ayrıştır
        $dosya_ids = explode(',', $data['dosyalar']);
        $dosya_ids = array_map('trim', $dosya_ids); // Boşlukları temizle

        // Eğer dosya ID'leri varsa, uploads tablosundan dosya yollarını al
        if (!empty($dosya_ids)) {
            // Uploads tablosunda eşleşen dosya yollarını al
            $placeholders = implode(',', array_fill(0, count($dosya_ids), '?'));
            $sql_files = "SELECT file_path FROM uploads WHERE id IN ($placeholders)";
            $stmt_files = $baglantim->prepare($sql_files);
            $stmt_files->execute($dosya_ids);

            // Dosya yollarını al
            $file_paths = $stmt_files->fetchAll(PDO::FETCH_COLUMN);
        } else {
            $file_paths = [];
        }

        // JSON olarak çıktı ver
        echo json_encode([
            "component" => $data,
            "files" => $file_paths
        ]);
    } else {
        echo json_encode(["error" => "Komponent bulunamadı."]);
    }
} catch (PDOException $e) {
    echo json_encode(["error" => "Database error: " . $e->getMessage()]);
}
?>