<?php
require_once 'inc/guvenlik.php'; // Güvenlik dosyasını dahil et
?>

<h5>Lokasyon Listesi</h5>
<table id="tablom" class="display nowrap" style="width:100%">

    <thead>
    <tr>
        <th>Lokasyon ID</th>
        <th>Konum</th>
        <th>Ad</th>
    </tr>
    </thead>

    <tbody>
    <?php
    try {
        // Veritabanı sorgusunu hazırlayın
        $liste = $baglantim->prepare("WITH RECURSIVE cte AS
        (
          SELECT id, CAST(ad AS CHAR(200)) AS ad,
                 CAST(ad AS CHAR(200)) AS yol,
                 CAST(ad AS CHAR(200)) AS path,
                 CAST(lokasyon_id AS CHAR(200)) AS katID,
                 0 as derinlik
          FROM lokasyon WHERE lokasyon_id = 0
          UNION ALL
          SELECT c.id,
                 CONCAT(REPEAT(' - ', cte.derinlik+1), c.ad),
                 CONCAT(cte.path, ' > ', c.ad),
                 CONCAT(cte.yol, ' > ', c.ad),
                 CONCAT(cte.id),
                 cte.derinlik+1
          FROM lokasyon c JOIN cte ON
          cte.id=c.lokasyon_id
        )
        SELECT * FROM cte ORDER BY path;");

        // Veriyi çalıştır
        $liste->execute();
        $sonuc = $liste->fetchAll();

        foreach ($sonuc as $satir) {
            // Güvenlik için çıktıları htmlspecialchars ile koru
            $id = htmlspecialchars($satir['id'], ENT_QUOTES, 'UTF-8');
            $katID = htmlspecialchars($satir['katID'], ENT_QUOTES, 'UTF-8');
            $ad = htmlspecialchars($satir['ad'], ENT_QUOTES, 'UTF-8');
            ?>
            <tr>
                <td><?php echo $id . ',' . $katID; ?></td>
                <td></td>
                <td><?php echo $ad; ?></td>
            </tr>
        <?php } ?>
        <?php
    } catch (PDOException $e) {
        // Hata durumunda genel bir mesaj göster
        echo '<tr><td colspan="3">Bir hata oluştu. Lütfen tekrar deneyin.</td></tr>';
        // İsteğe bağlı olarak log kaydını tutabilirsiniz (hataların kaydedilmesi).
    }
    ?>
    </tbody>

    <tfoot>
    <tr>
        <th></th>
        <th></th>
        <th></th>
        <th></th>
    </tr>
    </tfoot>
</table>

<script>
        $(document).ready(function () {

            var benimTablom = $('#tablom').DataTable({
                responsive: true,
                AutoWidth: false,
                searchHighlight: true,
                "pageLength": 10, // varsayilan olacak gosterilecek kayit
                columns: [
                    {title: "Id", "data": "iD", defaultContent: '', "visible": false},
                    {title: "No", "data": "no", "width": "2%"},
                    {title: "Lokasyon", "data": "lokasyon", "width": "100%"},
                    {title: "İşlemler", "data": "iD", "width": "1%"},


                ],
                columnDefs: [
                    {
                        searchable: false,
                        orderable: false,
                        targets: 1
                    },
                    {targets: [0, 1], searchable: false}, // arama yapilmamasini istedigimiz kolanlar
                    {"bSortable": false, "aTargets": [0, 1, 2, 3]}, // siralama olmamasini istedigimiz hucre 1, 3, 5 vs gibi
                    {"targets": 0, "data": 'iD'},
                    {"targets": 1, "data": 'no'},
                    {"targets": 2, "data": 'lokasyon'},


                    {
                        "targets": [3],
                        "data": 'iD',
                        "render": function (data) {
                            return '<div class="btn-group"><a href="index.php?sayfa=LokasyonDuzenle&LokasyonDuzenleID=' + data + '"> <button class="btn btn-sm btn-primary mx-1 duzenleBTN" id=' + data + '><i class="fa fa-pencil"></i></button></a> <button class="btn btn-sm btn-danger mx-1 LoksilBTN" id=' + data + '><i class="fa fa-trash-can"></button></div>'
                        },
                    },

                    //aramada vurgulanmasını ıstemedıgımız kolonu secelım.
                    {
                        targets: [0, 1],
                        className: 'search-hilite',
                    },
                    //aramada vurgulanmasını ıstemedıgımız kolonu secelım.

                ],
                order: [[0, '']],
                language: {
                    sInfoEmpty: '',
                    info: 'Sayfa : _PAGE_ / _PAGES_',
                    infoEmpty: 'Kayit bulunamadi',
                    infoFiltered: '(_MAX_ kayıt icinden arandi)',
                    lengthMenu: '_MENU_ &nbsp;&nbsp;kayıt göster',
                    zeroRecords: 'Aramada kayit bulunamadi',
                    sSearch: 'Ara:',
                    sEmptyTable: 'Veritabaninda kayit bulunamadi',
                },
            });

            //aramada vurgulanmasını ıstemedıgımız kolonu secelım.
            benimTablom.on('draw', function () {
                var body = $('.search-hilite', benimTablom.table().body());

                body.unhighlight();
                // body.highlight(benimTablom.search());
            });
            //aramada vurgulanmasını ıstemedıgımız kolonu secelım.

            buildSelect(benimTablom);
            benimTablom.on('draw', function () {
                buildSelect(benimTablom);
            });

            // no tablo sutununa sıra no eklesın
            benimTablom.on('order.dt search.dt', function () {
                let i = 1;

                benimTablom.cells(null, 1, {search: 'applied', order: 'applied'}).every(function (cell) {
                    this.data(i++);
                });
            }).draw();
            // no tablo sutununa sıra no eklesın
        });

        function buildSelect(benimTablom) {
            benimTablom.columns([]).every(function () { // benimTablom.columns([2, 3]).every(function () { bu satir boyle olursa 2 ve 3. sutunlarin altinda acilir menu ile filtreleme yapar
                var column = benimTablom.column(this, {search: 'applied'});
                var select = $('<select><option value=""></option></select>')
                    .appendTo($(column.footer()).empty())
                    .on('change', function () {
                        var val = $.fn.dataTable.util.escapeRegex(
                            $(this).val()
                        );

                        column
                            .search(val ? '^' + val + '$' : '', true, false)
                            .draw();
                    });

                column.data().unique().sort().each(function (d, j) {
                    select.append('<option value="' + d + '">' + d + '</option>');
                });

                // The rebuild will clear the exisiting select, so it needs to be repopulated
                var currSearch = column.search();
                console.log(currSearch)
                if (currSearch) {
                    var unescaped = currSearch.replace(/\\/g, '');
                    console.log(unescaped)
                    select.val(unescaped.substring(1, unescaped.length - 1));
                }
            });


        }


    </script>